/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_MANGLR_HPP_
#define _HEAVY_CONTEXT_WSTD_MANGLR_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlCast.h"
#include "HvSignalEnvelope.h"
#include "HvControlBinop.h"
#include "HvSignalVar.h"
#include "HvControlIf.h"
#include "HvControlSlice.h"
#include "HvControlDelay.h"
#include "HvControlVar.h"
#include "HvMath.h"
#include "HvSignalLine.h"

class Heavy_WSTD_MANGLR : public HeavyContext {

 public:
  Heavy_WSTD_MANGLR(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_MANGLR();

  const char *getName() override { return "WSTD_MANGLR"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        CRSHR = 0xE2DA4DC3, // Crshr
        FLDR = 0xE42C892E, // Fldr
        GAIN = 0x677821DA, // Gain
        LMTR = 0xCB23DC60, // Lmtr
        MIX = 0x97D46AC6, // Mix
        SMTHR = 0xD88E26F9, // Smthr
        SQNC = 0x53F863DB, // Sqnc
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_NnFQC02Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_icek4v4e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IlkgNkKt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kFgP0wWc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GD16kUnS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RyBD3G1n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rpktxyFI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4yqQYskf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_53LhFUAy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GDoI0cpb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qpf7h4dz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2YlDXYnd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PXhJ5RdN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TIYJj84S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zOOKXITg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PcMmMQ1z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4xVD7IB9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vjpCEPIS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iT3esoXs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8ivWCotc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iQ4j9j7j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_FR9sOHX5_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_YbG6FC8O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_91srT3WE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cV3MphGf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9F8oghn7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vMHiwQSn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NXrpTWdj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_4FrwURaA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_sZiGxnyK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_kHmUn0m3_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_1QdgwoWh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PIfUZ1zV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ai5fCRcE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JvrftFSG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ti3g1X2s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sErWSxiY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_85pv7UMy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gQ12S7qJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zzAZl9sY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_B4FY0Q05_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wHVdig7i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_O7OTxCIg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_dbuZTaPo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_koTcBoyV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_RYGnSiWY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EXxcsd8U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZBx1iYf5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ou5QMgQ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KWXd3icg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zkfHV11R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Y7MP1XeI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jVXx1gWE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZWoV8ML1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2I1f9ozG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_duszED6g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vPRCj8EX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_1x0MzRA0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_zzjdFtcH_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_2QTKQxeC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7FtmDcbn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SPO01iWe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uLU5rF4h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7TBu1XGf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BOOCJxgZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Stp8PyiP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6i868CjP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pG1tvDXi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XyzVthUk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_URKSIGHD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_mEp1tI3v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_LqNyG4xI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_84tMNWaX_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_sjzGsQyn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tBG4y3YW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lyGKc6Ar_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AYavMkr4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7jGYvA5S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_X0MoHDRt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wwWkPd8J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MrIsm6NU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_T2sE2lVS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ctj8JusS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_25zEz9q7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_5HEqktUh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_67kiLj0T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ozdHqj4I_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_j1wVPa8b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CZBQLczO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PpZnLG07_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e6o8cjgB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AlzIC5D8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jlSl5quS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8bkHmESC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_l3GXM8gE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LbTjgspe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MyEMReJh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vOuaVKyz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_iMk6N7hF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_w5nmsPau_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_vq9hBfB2_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_1O0gjIOg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ievp5dBp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vwX43GhM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mLlO0nvJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sYkD9Wav_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9wOlcHyE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_agkbEJKf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Z8TqSIi1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KCvhy9Ox_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uBshCC4e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QpOG7vZP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_CbLIJLIN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_JXCwPef6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_LgWTM0SK_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_Pz7q9O4h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zp08jBbd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_x5T3UqU7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xeViEALV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tLT7VPkp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_91wIpb3j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_D4WGdGq3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_d6TqPEcM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6BfVhWzg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zCoutTDw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yLTlZUq2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_8QxMlKnF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_5h26AVb8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_RUAPoK4y_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_Dfd8NzgJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aiVg5yMP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ajbXkNgO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vBsTb81X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UA8BGfGD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZH2tGusQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NhS7ZwVV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QIR7vXqP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_G7CMTlHh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PugpqtVu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DZpBtdXO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_rocIBvyQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_y7VvRN5B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_U1dEM2EE_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_oMeEXHFl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IXh1pdjR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qPiCbWNn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uL5Gy7f2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YozpetjR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bWY6jwHb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_f5EHoALv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MmDbFa8R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rSp9sQBx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_25NBJePX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XyizBdPE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_lOXCPCaB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_q8xWi110_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ulkAWo9e_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_v0t6esvJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lhUYQzKn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yXnREevl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hreo9X9b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ji9V4p3u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TSsOMuja_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sPZ1IhgE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_liXPQ98X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aIg02H4b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_t2FMTbIB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Br2DHpqj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_R2iSSuzE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_A3BouYLt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_XRUJPdyk_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_Oy2RDiNP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_goJ7Xg8I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tKvBZ02Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u69AzDpK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KKd1wt04_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zfJU0ppc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6EamCHjW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2q7N9cje_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oJ6TtzsB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XrEmndix_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PINdUjtq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_26vMdN26_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Bg4HKnbl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_gWZpELYh_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_wwnLutbp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dPrDUiNP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6905fz7c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0DLnL5gD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_meL3mylg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gKPqOgLF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HWILnghQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wCOMLvFd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V5qDvfIe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gLkfa3ix_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NVitKE7c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rXXVcCMZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8TumB9mk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Rn0QB1qt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_I5nupYE1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_i2gfeYhi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ggUAHZLg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bBmw7O9Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9CYYDLVY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ryXj6b2v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NxnhevJD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AELCY57H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Vn0groAE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1LqDjRli_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dtZJXUT3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r65DbyQx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8J19anby_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1oceMToi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_55ZmmHpo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aRVwaE3d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LQu4HF8y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uXsDTWly_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_839vi551_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_a4349JL3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dqeGG2kp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_arNlBEtw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mudGYInl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iX2Mtv09_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_urH0fl59_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xvuezEUk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nL4Bxbh0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_M5cNxMfT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0HmAL4Kc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ksDpRkHO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vNNjAvdX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zE8E1jZk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ul2GERqk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6TyLqb4F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sG6YlsWS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BlSrr41e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kcrK5Q0v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PabEN92s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XDjp6tSf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Zwk1gywR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lTa7JaGF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DvUsMCNE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_r5EVPaKw_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Xf3xyJHX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sorhhRPl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_vx0JALbW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_kySda359_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_UhbQbdMI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_EColGcM4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_b7kpb7st_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_lfLfm8pN_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Pyk85ZvW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3Psh4dKO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_oxIFhCT4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_XVw4fp9R_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_B0kWcHiE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_CLjfhHWW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_bjulhATA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_iJP1oWSc_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_P9Ml3uWc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Szmwv7FY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_jXpH5KgA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_K3xjtQbC_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_6PVKzSkP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eI1N496k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iR3m3frS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SG0gLPYX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_cc4fQHNV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_3pKxOdiT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_nbunmxn0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_oXOfsHRh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_B3TXEzNz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oqSxCB5J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7xY2XvCL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UdS6uvn8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YjBMhJYc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8UGVW33H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UCneoRUo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_syS86LDW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yooeLviO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lKgVwgB5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_J0Upq10n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AlM6T6rA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PiZWXO7Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_wkjx03wu_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_bKrq6NIf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aA5vH6l1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_4eJuEi1P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MxcwchKi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_R6AUOBmE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RxvjtDjF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8bNGln67_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oSnpOx8E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_M852Uu8W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_75HgF57O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_polr6H6a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2aZg1XPn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nH4Zcl3C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xm6Uc1oG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NacoAsBN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_c5mf1clt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_sjCA0yp4_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_GlO1ujHO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6tmSJdrp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_r8u7pMYE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CkLbDwQw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fnKo8X35_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_E50JmW2r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_63CqJSRo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_wfG96rBe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_n9F8M3s9_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_yFRNNXWF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KHdfZsjj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dCJPwJ5v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uM54dqKo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OQYphrmn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NFfpCgz2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EyhP3wvd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_08pOpgd8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SGMD1tdE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_j9eYwpFI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TTO5X7sV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_KXDfinBq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_T2O6p5S7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_iqvHhXIl_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_p9ldyWyj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_712XIgnI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Yj2kx1Xm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fNW1A7nh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ract6ZBv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_j8UUKzwg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jv1ehwkq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0DuygGJh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Uctwe5Ox_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dzCDdbrq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2g0spmuu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_WKMfRjQS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_mZXYjJtF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_55cbSPXA_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_vpFwQZI7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AduB2KXg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RPGOfnXq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Yl1GVSev_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JVUP5YRf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HyVS3ffc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_42eS06yS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qRHVWnUp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_v8NVDy5M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GFRafgWm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0WBPKusB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_cb8uoENz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_hR05TLeq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_tXqyN19w_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_mWst5TOm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SfZPIvtg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_keaJELY4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rzkjvcPB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_J3Hdn0Is_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_54UFl05A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_haSFLrGB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DL9Mfixe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xLvnvFto_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_v8yMhriO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8AyuJbko_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_bZ2MlZ4n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_KcTcbym9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_YRCK4LNb_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_Q3jVnUMO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kq3ZTdvn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AtEKCmus_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i6dou7rj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HJzeqYhj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dVXWlXH8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_G1Il6uNP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kNJIgRys_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_urCOWPK7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VHI3D8It_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BrBrkfz4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_X9HGMk54_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_OOxZi3LQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_8QcEds4u_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_CEnsTTwN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_THMKnwWR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vxvQKA19_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TX4wV6lp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4Kn133Se_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OfLb0kAh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0NQh37Q9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FnXYU2CK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UoE8epMQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UlL2GNS8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HvWTcCVr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_s5LEhhsh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_BkUgpApd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_JqVk6b9O_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_hdeMJuxE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BP2RI16r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ua2q5sIC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Bnintw71_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MQN2V0Tt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iyoDE3cW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gACtNyF2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TmBKqa0E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xzri9dID_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ed5Ir7ew_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZAOKMxEP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_s4H3CBLu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_wIaCbJGB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_uaQ1YQcp_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_QilEbcwx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_M7D1tNIh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FnCaMiAE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zLZrkvtq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hzPxIhTS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gp9GNCc1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eEY5Ivxv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_j2WtvqB7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FQHnX6J6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O0Nwp8UJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uuyARd0R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_caN2zBZR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_A1xEXqXZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_MYXVxmLh_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_wgsh0t8Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_57F5DWfc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CkdeAcgr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LdJZCSFU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W0tl2A2U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_scgRLynG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mryXmkfi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PqYGTOGy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RJYWxUMF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vVH9CnqO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kgEa2XQZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Y1LCn2yM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_gayfFHfs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_UkzHl7Ms_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_Oy73Lovb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_doRChkTW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dnwg8Fh1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pyC877Sq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ljn8jdrR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9o1gU7of_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Xv0rEWpa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_He7KC9ey_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_N2Z4sQY1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_T3siChZV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RG1JeNZg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_WMnAeGSk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_nxdImuAc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_8FT6JpgZ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_wdyIgDVP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hIVRgDmL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xP6zMj2G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Jh7VyYYn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sE4FmMvZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0iBPfV0G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HDb1zruD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_h88KgJJr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9G6Qt1UU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CuDcpD7V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L9b9rHau_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_CJNvHvpU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_hWqxUOJU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_VIsqhEBd_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_qpuLm9Qd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_c1XCuifU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7SzAXmlg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s5KL6o9O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JGg8GsiK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4qCPehQF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qo132hVq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IdAQ9dTU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_suZNmMkD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aYBJhdf7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iyoWY1yH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0Jo46sj4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_f1gBBad7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dzBs56fB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eVg0bZze_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_n1oMQ1or_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tDgIqYIc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6A12FuFw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ymYyWxoX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MxCU5hVQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jBOQbKTG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ikh8h6DD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zB4zZ2Cn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_orhtrUnE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_40nU8DxY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tgP0Iez6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Pe5JM6yV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iQrt90bR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xkWh7DQO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pPk5p4Fw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Bt6I8DDp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8NXIGyFk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9JNHti8Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pl7ogU0b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ynbqdx7C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_opATxNLG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FQ8WKO9T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zNGOKbmk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N7ZSjayR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pIk9Ynjs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KB5qWCMw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_i7PrLJj7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8dQRTJ0v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_f8AdWTRl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3NLjbXXF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Gj9Yx5eM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WUvJWRzs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eWRwbJSp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IxIjy1yy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LVYvSO28_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ge7oGx4w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RYfL0apr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QowWabDp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dof2096m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zETkiTAq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1d0fxZ2T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_LyKDXWyn_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Kcdez81n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_X2zZBH7Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_0E9SOPVu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_NCOZqNpf_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_pQOccOX6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iHC1YKkG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_GiqFrEO4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_glk0GY2M_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_XvaEznUX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vw3ScSwF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_NVnaKBup_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_jhQhRycZ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_5URpgoK2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_AKr8nFoX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_xxx2dMx4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Q0bJguZd_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_qr3IDEY8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zuePTHp5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_xSNs5DW4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_CMMzespj_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_rWPodFI0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F9FzUKXJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LZzh5SNu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nXWYifJ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vziYoy3K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_XmnsnzEg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_Wtw0GUeH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_DrObLSba_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9uzbjY46_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wl3eZRht_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9KErg4qF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7iNavZ4S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HHySNVK4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MmFXaURZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0F1RN8vi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uw4zwq7J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_B6ylrv2P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VeB23oCj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aYtlAHjF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FZ9VdxTG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PasZFhfZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_g9Ql5aSY_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_x7OXI6b6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_acsrg6T9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_amfT2AgM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xAzfaPD2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xpbk5IWc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Bf9I2Waj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JAdTv5e7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hHztLITt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ho74zzXs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_S1DUEuDP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9U4s4Sxb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pL4lZbcl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C8WBOZzj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uiiPpFWC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_uBweunM3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Yf78NnL7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VMhy3yb3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_pCOC6aGS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_s6dZb2m7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vimH59Sz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y80x44BQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mw8HFibN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4qCrMEhM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ndlg7Oj6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_v9aTvFDC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kvnBGoDu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ni2wpFgP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_u8BBwNbT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_URlzXmXc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Smdzmd5G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tBF9gqZh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Smn1LcUm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_uaPIeLye_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fKeWCIpK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3IUEhKcN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8Acs77G2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_OQ9dvt8q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ROHy0QDD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rLgreRKT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_a1rQ6Pka_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DOjfhsGp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_BcUCxyIF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_YdbgW1jH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_E2CnPw4S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0PwMitDv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_hWXLjUds_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_WT8fUvuN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_RX2magDI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2CsfgG9d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9L3QVJzj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_YlFZRXyo_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_WqlcTdqD;
  SignalLine sLine_Rn0Xkg1y;
  SignalLine sLine_rp3wD9rq;
  SignalLine sLine_0WFl1CmR;
  SignalLine sLine_dd3EDFDj;
  SignalLine sLine_lEIo5vcb;
  SignalLine sLine_huB7Y2WV;
  SignalLine sLine_SySItBN8;
  SignalLine sLine_xO1ntkR7;
  SignalLine sLine_SESCXPR5;
  SignalLine sLine_E6Akevzs;
  SignalLine sLine_fWC4fTQn;
  SignalEnvelope sEnv_nbunmxn0;
  SignalEnvelope sEnv_oXOfsHRh;
  SignalLine sLine_f4ctMpoG;
  SignalLine sLine_gCoVXxsJ;
  SignalLine sLine_Ir7HPw0m;
  SignalLine sLine_DeCdipZ6;
  SignalLine sLine_iF0MyzzS;
  SignalLine sLine_9A5WEpUm;
  SignalLine sLine_1qO2CIPA;
  SignalLine sLine_lwFsnvKi;
  SignalLine sLine_DdMLqQ1n;
  SignalLine sLine_VtpwnTD0;
  SignalLine sLine_gGv292lZ;
  SignalLine sLine_5LJkXRmk;
  SignalLine sLine_HCVn7SlN;
  SignalLine sLine_BPBtlzqv;
  SignalLine sLine_6NVw6gWs;
  SignalLine sLine_XXb9kCR5;
  SignalLine sLine_FNnbHw25;
  SignalLine sLine_btTEoo8f;
  SignalEnvelope sEnv_Wtw0GUeH;
  SignalEnvelope sEnv_DrObLSba;
  SignalLine sLine_fQJIP8Ek;
  SignalLine sLine_h7bIsxRj;
  SignalLine sLine_Dsz2iBJg;
  SignalLine sLine_HLd4v4O1;
  SignalLine sLine_VeK86sD3;
  SignalLine sLine_Q8psKNZG;
  SignalLine sLine_2mQEa76s;
  SignalLine sLine_ZC8Rf3e5;
  ControlVar cVar_NnFQC02Z;
  ControlBinop cBinop_icek4v4e;
  ControlBinop cBinop_IlkgNkKt;
  ControlBinop cBinop_kFgP0wWc;
  ControlBinop cBinop_GD16kUnS;
  ControlBinop cBinop_4yqQYskf;
  ControlBinop cBinop_GDoI0cpb;
  ControlBinop cBinop_Qpf7h4dz;
  ControlBinop cBinop_2YlDXYnd;
  ControlVar cVar_PXhJ5RdN;
  ControlVar cVar_TIYJj84S;
  ControlVar cVar_zOOKXITg;
  ControlVar cVar_PcMmMQ1z;
  ControlVar cVar_4xVD7IB9;
  ControlBinop cBinop_vjpCEPIS;
  ControlVar cVar_8ivWCotc;
  ControlVar cVar_iQ4j9j7j;
  ControlIf cIf_4FrwURaA;
  ControlIf cIf_sZiGxnyK;
  ControlDelay cDelay_1QdgwoWh;
  ControlBinop cBinop_JvrftFSG;
  ControlBinop cBinop_Ti3g1X2s;
  ControlIf cIf_O7OTxCIg;
  ControlIf cIf_dbuZTaPo;
  ControlDelay cDelay_RYGnSiWY;
  ControlBinop cBinop_ou5QMgQ5;
  ControlBinop cBinop_KWXd3icg;
  ControlIf cIf_vPRCj8EX;
  ControlIf cIf_1x0MzRA0;
  ControlDelay cDelay_2QTKQxeC;
  ControlBinop cBinop_uLU5rF4h;
  ControlBinop cBinop_7TBu1XGf;
  ControlIf cIf_mEp1tI3v;
  ControlIf cIf_LqNyG4xI;
  ControlDelay cDelay_sjzGsQyn;
  ControlBinop cBinop_AYavMkr4;
  ControlBinop cBinop_7jGYvA5S;
  ControlIf cIf_5HEqktUh;
  ControlIf cIf_67kiLj0T;
  ControlDelay cDelay_j1wVPa8b;
  ControlBinop cBinop_e6o8cjgB;
  ControlBinop cBinop_AlzIC5D8;
  ControlIf cIf_iMk6N7hF;
  ControlIf cIf_w5nmsPau;
  ControlDelay cDelay_1O0gjIOg;
  ControlBinop cBinop_mLlO0nvJ;
  ControlBinop cBinop_sYkD9Wav;
  ControlIf cIf_CbLIJLIN;
  ControlIf cIf_JXCwPef6;
  ControlDelay cDelay_Pz7q9O4h;
  ControlBinop cBinop_xeViEALV;
  ControlBinop cBinop_tLT7VPkp;
  ControlIf cIf_8QxMlKnF;
  ControlIf cIf_5h26AVb8;
  ControlDelay cDelay_Dfd8NzgJ;
  ControlBinop cBinop_vBsTb81X;
  ControlBinop cBinop_UA8BGfGD;
  ControlIf cIf_rocIBvyQ;
  ControlIf cIf_y7VvRN5B;
  ControlDelay cDelay_oMeEXHFl;
  ControlBinop cBinop_uL5Gy7f2;
  ControlBinop cBinop_YozpetjR;
  ControlIf cIf_lOXCPCaB;
  ControlIf cIf_q8xWi110;
  ControlDelay cDelay_v0t6esvJ;
  ControlBinop cBinop_Hreo9X9b;
  ControlBinop cBinop_Ji9V4p3u;
  ControlIf cIf_R2iSSuzE;
  ControlIf cIf_A3BouYLt;
  ControlDelay cDelay_Oy2RDiNP;
  ControlBinop cBinop_u69AzDpK;
  ControlBinop cBinop_KKd1wt04;
  ControlIf cIf_26vMdN26;
  ControlIf cIf_Bg4HKnbl;
  ControlDelay cDelay_wwnLutbp;
  ControlBinop cBinop_0DLnL5gD;
  ControlBinop cBinop_meL3mylg;
  SignalVarf sVarf_ffqRprqn;
  SignalVarf sVarf_d1800YhA;
  SignalVarf sVarf_m0DNPezF;
  SignalVarf sVarf_oJlT3zb7;
  SignalVarf sVarf_z4yoMAHs;
  SignalVarf sVarf_qHqwsHNg;
  SignalVarf sVarf_jnZ32q2h;
  SignalVarf sVarf_S40HZLde;
  ControlVar cVar_DvUsMCNE;
  ControlSlice cSlice_Xf3xyJHX;
  ControlVar cVar_sorhhRPl;
  ControlSlice cSlice_UhbQbdMI;
  ControlVar cVar_EColGcM4;
  ControlSlice cSlice_Pyk85ZvW;
  ControlVar cVar_3Psh4dKO;
  ControlSlice cSlice_B0kWcHiE;
  ControlVar cVar_CLjfhHWW;
  ControlSlice cSlice_P9Ml3uWc;
  ControlVar cVar_Szmwv7FY;
  ControlDelay cDelay_6PVKzSkP;
  ControlVar cVar_SG0gLPYX;
  ControlIf cIf_cc4fQHNV;
  ControlIf cIf_3pKxOdiT;
  ControlBinop cBinop_B3TXEzNz;
  ControlBinop cBinop_7xY2XvCL;
  ControlBinop cBinop_UdS6uvn8;
  ControlBinop cBinop_UCneoRUo;
  ControlBinop cBinop_yooeLviO;
  ControlSlice cSlice_bKrq6NIf;
  ControlVar cVar_aA5vH6l1;
  SignalVarf sVarf_B9lhuAGz;
  SignalVarf sVarf_MrV0XEXO;
  SignalVarf sVarf_hpJ6ak4w;
  SignalVarf sVarf_Edw4EHVf;
  SignalVarf sVarf_xT0Pc788;
  SignalVarf sVarf_FsbK5iFM;
  ControlBinop cBinop_RxvjtDjF;
  ControlBinop cBinop_nH4Zcl3C;
  ControlVar cVar_NacoAsBN;
  ControlVar cVar_c5mf1clt;
  ControlIf cIf_63CqJSRo;
  ControlIf cIf_wfG96rBe;
  ControlDelay cDelay_yFRNNXWF;
  ControlBinop cBinop_uM54dqKo;
  ControlBinop cBinop_OQYphrmn;
  ControlIf cIf_KXDfinBq;
  ControlIf cIf_T2O6p5S7;
  ControlDelay cDelay_p9ldyWyj;
  ControlBinop cBinop_fNW1A7nh;
  ControlBinop cBinop_Ract6ZBv;
  ControlIf cIf_WKMfRjQS;
  ControlIf cIf_mZXYjJtF;
  ControlDelay cDelay_vpFwQZI7;
  ControlBinop cBinop_Yl1GVSev;
  ControlBinop cBinop_JVUP5YRf;
  ControlIf cIf_cb8uoENz;
  ControlIf cIf_hR05TLeq;
  ControlDelay cDelay_mWst5TOm;
  ControlBinop cBinop_rzkjvcPB;
  ControlBinop cBinop_J3Hdn0Is;
  ControlIf cIf_bZ2MlZ4n;
  ControlIf cIf_KcTcbym9;
  ControlDelay cDelay_Q3jVnUMO;
  ControlBinop cBinop_i6dou7rj;
  ControlBinop cBinop_HJzeqYhj;
  ControlIf cIf_X9HGMk54;
  ControlIf cIf_OOxZi3LQ;
  ControlDelay cDelay_CEnsTTwN;
  ControlBinop cBinop_TX4wV6lp;
  ControlBinop cBinop_4Kn133Se;
  ControlIf cIf_s5LEhhsh;
  ControlIf cIf_BkUgpApd;
  ControlDelay cDelay_hdeMJuxE;
  ControlBinop cBinop_Bnintw71;
  ControlBinop cBinop_MQN2V0Tt;
  ControlIf cIf_s4H3CBLu;
  ControlIf cIf_wIaCbJGB;
  ControlDelay cDelay_QilEbcwx;
  ControlBinop cBinop_zLZrkvtq;
  ControlBinop cBinop_hzPxIhTS;
  ControlIf cIf_caN2zBZR;
  ControlIf cIf_A1xEXqXZ;
  ControlDelay cDelay_wgsh0t8Q;
  ControlBinop cBinop_LdJZCSFU;
  ControlBinop cBinop_W0tl2A2U;
  ControlIf cIf_Y1LCn2yM;
  ControlIf cIf_gayfFHfs;
  ControlDelay cDelay_Oy73Lovb;
  ControlBinop cBinop_pyC877Sq;
  ControlBinop cBinop_Ljn8jdrR;
  ControlIf cIf_WMnAeGSk;
  ControlIf cIf_nxdImuAc;
  ControlDelay cDelay_wdyIgDVP;
  ControlBinop cBinop_Jh7VyYYn;
  ControlBinop cBinop_sE4FmMvZ;
  ControlIf cIf_CJNvHvpU;
  ControlIf cIf_hWqxUOJU;
  ControlDelay cDelay_qpuLm9Qd;
  ControlBinop cBinop_s5KL6o9O;
  ControlBinop cBinop_JGg8GsiK;
  SignalVarf sVarf_jP8Zpr5L;
  SignalVarf sVarf_wvYBB5N0;
  SignalVarf sVarf_WDxp3u8O;
  SignalVarf sVarf_wwBRkokE;
  SignalVarf sVarf_UOPeTe1m;
  SignalVarf sVarf_nSgd3l3S;
  SignalVarf sVarf_HPKEEgF9;
  SignalVarf sVarf_I1hb4J7u;
  ControlVar cVar_1d0fxZ2T;
  ControlSlice cSlice_Kcdez81n;
  ControlVar cVar_X2zZBH7Z;
  ControlSlice cSlice_pQOccOX6;
  ControlVar cVar_iHC1YKkG;
  ControlSlice cSlice_XvaEznUX;
  ControlVar cVar_vw3ScSwF;
  ControlSlice cSlice_5URpgoK2;
  ControlVar cVar_AKr8nFoX;
  ControlSlice cSlice_qr3IDEY8;
  ControlVar cVar_zuePTHp5;
  ControlDelay cDelay_rWPodFI0;
  ControlVar cVar_nXWYifJ6;
  ControlIf cIf_vziYoy3K;
  ControlIf cIf_XmnsnzEg;
  ControlBinop cBinop_9uzbjY46;
  ControlBinop cBinop_9KErg4qF;
  ControlBinop cBinop_7iNavZ4S;
  ControlBinop cBinop_0F1RN8vi;
  ControlBinop cBinop_B6ylrv2P;
  ControlSlice cSlice_x7OXI6b6;
  ControlVar cVar_acsrg6T9;
  SignalVarf sVarf_Q4ey7pyx;
  SignalVarf sVarf_7vorwxen;
  SignalVarf sVarf_HyjJ8O4i;
  SignalVarf sVarf_74iFaBF1;
  SignalVarf sVarf_23av4EMO;
  SignalVarf sVarf_oHGh5CZB;
  ControlBinop cBinop_Bf9I2Waj;
  ControlBinop cBinop_C8WBOZzj;
  ControlVar cVar_uBweunM3;
  SignalVarf sVarf_670Lzilk;
  SignalVarf sVarf_wEkPf3Zi;
  SignalVarf sVarf_NC1HmHvH;
  SignalVarf sVarf_9ViDh31u;
  ControlBinop cBinop_y80x44BQ;
};

#endif // _HEAVY_CONTEXT_WSTD_MANGLR_HPP_
