/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_MANGLR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_MANGLR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_MANGLR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_MANGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_MANGLR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_MANGLR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_MANGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_MANGLR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_MANGLR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_MANGLR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_MANGLR::Heavy_WSTD_MANGLR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_WqlcTdqD);
  numBytes += sLine_init(&sLine_Rn0Xkg1y);
  numBytes += sLine_init(&sLine_rp3wD9rq);
  numBytes += sLine_init(&sLine_0WFl1CmR);
  numBytes += sLine_init(&sLine_dd3EDFDj);
  numBytes += sLine_init(&sLine_lEIo5vcb);
  numBytes += sLine_init(&sLine_huB7Y2WV);
  numBytes += sLine_init(&sLine_SySItBN8);
  numBytes += sLine_init(&sLine_xO1ntkR7);
  numBytes += sLine_init(&sLine_SESCXPR5);
  numBytes += sLine_init(&sLine_E6Akevzs);
  numBytes += sLine_init(&sLine_fWC4fTQn);
  numBytes += sEnv_init(&sEnv_nbunmxn0, 512, 256);
  numBytes += sEnv_init(&sEnv_oXOfsHRh, 512, 256);
  numBytes += sLine_init(&sLine_f4ctMpoG);
  numBytes += sLine_init(&sLine_gCoVXxsJ);
  numBytes += sLine_init(&sLine_Ir7HPw0m);
  numBytes += sLine_init(&sLine_DeCdipZ6);
  numBytes += sLine_init(&sLine_iF0MyzzS);
  numBytes += sLine_init(&sLine_9A5WEpUm);
  numBytes += sLine_init(&sLine_1qO2CIPA);
  numBytes += sLine_init(&sLine_lwFsnvKi);
  numBytes += sLine_init(&sLine_DdMLqQ1n);
  numBytes += sLine_init(&sLine_VtpwnTD0);
  numBytes += sLine_init(&sLine_gGv292lZ);
  numBytes += sLine_init(&sLine_5LJkXRmk);
  numBytes += sLine_init(&sLine_HCVn7SlN);
  numBytes += sLine_init(&sLine_BPBtlzqv);
  numBytes += sLine_init(&sLine_6NVw6gWs);
  numBytes += sLine_init(&sLine_XXb9kCR5);
  numBytes += sLine_init(&sLine_FNnbHw25);
  numBytes += sLine_init(&sLine_btTEoo8f);
  numBytes += sEnv_init(&sEnv_Wtw0GUeH, 512, 256);
  numBytes += sEnv_init(&sEnv_DrObLSba, 512, 256);
  numBytes += sLine_init(&sLine_fQJIP8Ek);
  numBytes += sLine_init(&sLine_h7bIsxRj);
  numBytes += sLine_init(&sLine_Dsz2iBJg);
  numBytes += sLine_init(&sLine_HLd4v4O1);
  numBytes += sLine_init(&sLine_VeK86sD3);
  numBytes += sLine_init(&sLine_Q8psKNZG);
  numBytes += sLine_init(&sLine_2mQEa76s);
  numBytes += sLine_init(&sLine_ZC8Rf3e5);
  numBytes += cVar_init_f(&cVar_NnFQC02Z, 0.0f);
  numBytes += cVar_init_f(&cVar_PXhJ5RdN, 0.0f);
  numBytes += cVar_init_f(&cVar_TIYJj84S, 0.0f);
  numBytes += cVar_init_f(&cVar_zOOKXITg, 0.0f);
  numBytes += cVar_init_f(&cVar_PcMmMQ1z, 0.0f);
  numBytes += cVar_init_f(&cVar_4xVD7IB9, 1.0f);
  numBytes += cVar_init_f(&cVar_8ivWCotc, 0.0f);
  numBytes += cVar_init_f(&cVar_iQ4j9j7j, 0.0f);
  numBytes += cIf_init(&cIf_4FrwURaA, false);
  numBytes += cIf_init(&cIf_sZiGxnyK, false);
  numBytes += cDelay_init(this, &cDelay_1QdgwoWh, 10.0f);
  numBytes += cIf_init(&cIf_O7OTxCIg, false);
  numBytes += cIf_init(&cIf_dbuZTaPo, false);
  numBytes += cDelay_init(this, &cDelay_RYGnSiWY, 10.0f);
  numBytes += cIf_init(&cIf_vPRCj8EX, false);
  numBytes += cIf_init(&cIf_1x0MzRA0, false);
  numBytes += cDelay_init(this, &cDelay_2QTKQxeC, 10.0f);
  numBytes += cIf_init(&cIf_mEp1tI3v, false);
  numBytes += cIf_init(&cIf_LqNyG4xI, false);
  numBytes += cDelay_init(this, &cDelay_sjzGsQyn, 10.0f);
  numBytes += cIf_init(&cIf_5HEqktUh, false);
  numBytes += cIf_init(&cIf_67kiLj0T, false);
  numBytes += cDelay_init(this, &cDelay_j1wVPa8b, 10.0f);
  numBytes += cIf_init(&cIf_iMk6N7hF, false);
  numBytes += cIf_init(&cIf_w5nmsPau, false);
  numBytes += cDelay_init(this, &cDelay_1O0gjIOg, 10.0f);
  numBytes += cIf_init(&cIf_CbLIJLIN, false);
  numBytes += cIf_init(&cIf_JXCwPef6, false);
  numBytes += cDelay_init(this, &cDelay_Pz7q9O4h, 10.0f);
  numBytes += cIf_init(&cIf_8QxMlKnF, false);
  numBytes += cIf_init(&cIf_5h26AVb8, false);
  numBytes += cDelay_init(this, &cDelay_Dfd8NzgJ, 10.0f);
  numBytes += cIf_init(&cIf_rocIBvyQ, false);
  numBytes += cIf_init(&cIf_y7VvRN5B, false);
  numBytes += cDelay_init(this, &cDelay_oMeEXHFl, 10.0f);
  numBytes += cIf_init(&cIf_lOXCPCaB, false);
  numBytes += cIf_init(&cIf_q8xWi110, false);
  numBytes += cDelay_init(this, &cDelay_v0t6esvJ, 10.0f);
  numBytes += cIf_init(&cIf_R2iSSuzE, false);
  numBytes += cIf_init(&cIf_A3BouYLt, false);
  numBytes += cDelay_init(this, &cDelay_Oy2RDiNP, 10.0f);
  numBytes += cIf_init(&cIf_26vMdN26, false);
  numBytes += cIf_init(&cIf_Bg4HKnbl, false);
  numBytes += cDelay_init(this, &cDelay_wwnLutbp, 10.0f);
  numBytes += sVarf_init(&sVarf_ffqRprqn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_d1800YhA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_m0DNPezF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oJlT3zb7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_z4yoMAHs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qHqwsHNg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jnZ32q2h, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_S40HZLde, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_DvUsMCNE, 0.0f);
  numBytes += cSlice_init(&cSlice_Xf3xyJHX, 1, -1);
  numBytes += cVar_init_f(&cVar_sorhhRPl, 1.0f);
  numBytes += cSlice_init(&cSlice_UhbQbdMI, 1, -1);
  numBytes += cVar_init_f(&cVar_EColGcM4, 0.0f);
  numBytes += cSlice_init(&cSlice_Pyk85ZvW, 1, -1);
  numBytes += cVar_init_f(&cVar_3Psh4dKO, 512.0f);
  numBytes += cSlice_init(&cSlice_B0kWcHiE, 1, -1);
  numBytes += cVar_init_f(&cVar_CLjfhHWW, 1.0f);
  numBytes += cSlice_init(&cSlice_P9Ml3uWc, 1, -1);
  numBytes += cVar_init_f(&cVar_Szmwv7FY, 1.0f);
  numBytes += cDelay_init(this, &cDelay_6PVKzSkP, 20.0f);
  numBytes += cVar_init_f(&cVar_SG0gLPYX, 0.0f);
  numBytes += cIf_init(&cIf_cc4fQHNV, false);
  numBytes += cIf_init(&cIf_3pKxOdiT, false);
  numBytes += cBinop_init(&cBinop_B3TXEzNz, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_bKrq6NIf, 1, -1);
  numBytes += cVar_init_f(&cVar_aA5vH6l1, 0.0f);
  numBytes += sVarf_init(&sVarf_B9lhuAGz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MrV0XEXO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hpJ6ak4w, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Edw4EHVf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xT0Pc788, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FsbK5iFM, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_NacoAsBN, 0.0f);
  numBytes += cVar_init_f(&cVar_c5mf1clt, 0.0f);
  numBytes += cIf_init(&cIf_63CqJSRo, false);
  numBytes += cIf_init(&cIf_wfG96rBe, false);
  numBytes += cDelay_init(this, &cDelay_yFRNNXWF, 10.0f);
  numBytes += cIf_init(&cIf_KXDfinBq, false);
  numBytes += cIf_init(&cIf_T2O6p5S7, false);
  numBytes += cDelay_init(this, &cDelay_p9ldyWyj, 10.0f);
  numBytes += cIf_init(&cIf_WKMfRjQS, false);
  numBytes += cIf_init(&cIf_mZXYjJtF, false);
  numBytes += cDelay_init(this, &cDelay_vpFwQZI7, 10.0f);
  numBytes += cIf_init(&cIf_cb8uoENz, false);
  numBytes += cIf_init(&cIf_hR05TLeq, false);
  numBytes += cDelay_init(this, &cDelay_mWst5TOm, 10.0f);
  numBytes += cIf_init(&cIf_bZ2MlZ4n, false);
  numBytes += cIf_init(&cIf_KcTcbym9, false);
  numBytes += cDelay_init(this, &cDelay_Q3jVnUMO, 10.0f);
  numBytes += cIf_init(&cIf_X9HGMk54, false);
  numBytes += cIf_init(&cIf_OOxZi3LQ, false);
  numBytes += cDelay_init(this, &cDelay_CEnsTTwN, 10.0f);
  numBytes += cIf_init(&cIf_s5LEhhsh, false);
  numBytes += cIf_init(&cIf_BkUgpApd, false);
  numBytes += cDelay_init(this, &cDelay_hdeMJuxE, 10.0f);
  numBytes += cIf_init(&cIf_s4H3CBLu, false);
  numBytes += cIf_init(&cIf_wIaCbJGB, false);
  numBytes += cDelay_init(this, &cDelay_QilEbcwx, 10.0f);
  numBytes += cIf_init(&cIf_caN2zBZR, false);
  numBytes += cIf_init(&cIf_A1xEXqXZ, false);
  numBytes += cDelay_init(this, &cDelay_wgsh0t8Q, 10.0f);
  numBytes += cIf_init(&cIf_Y1LCn2yM, false);
  numBytes += cIf_init(&cIf_gayfFHfs, false);
  numBytes += cDelay_init(this, &cDelay_Oy73Lovb, 10.0f);
  numBytes += cIf_init(&cIf_WMnAeGSk, false);
  numBytes += cIf_init(&cIf_nxdImuAc, false);
  numBytes += cDelay_init(this, &cDelay_wdyIgDVP, 10.0f);
  numBytes += cIf_init(&cIf_CJNvHvpU, false);
  numBytes += cIf_init(&cIf_hWqxUOJU, false);
  numBytes += cDelay_init(this, &cDelay_qpuLm9Qd, 10.0f);
  numBytes += sVarf_init(&sVarf_jP8Zpr5L, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wvYBB5N0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WDxp3u8O, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wwBRkokE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UOPeTe1m, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nSgd3l3S, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HPKEEgF9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_I1hb4J7u, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_1d0fxZ2T, 0.0f);
  numBytes += cSlice_init(&cSlice_Kcdez81n, 1, -1);
  numBytes += cVar_init_f(&cVar_X2zZBH7Z, 1.0f);
  numBytes += cSlice_init(&cSlice_pQOccOX6, 1, -1);
  numBytes += cVar_init_f(&cVar_iHC1YKkG, 0.0f);
  numBytes += cSlice_init(&cSlice_XvaEznUX, 1, -1);
  numBytes += cVar_init_f(&cVar_vw3ScSwF, 512.0f);
  numBytes += cSlice_init(&cSlice_5URpgoK2, 1, -1);
  numBytes += cVar_init_f(&cVar_AKr8nFoX, 1.0f);
  numBytes += cSlice_init(&cSlice_qr3IDEY8, 1, -1);
  numBytes += cVar_init_f(&cVar_zuePTHp5, 1.0f);
  numBytes += cDelay_init(this, &cDelay_rWPodFI0, 20.0f);
  numBytes += cVar_init_f(&cVar_nXWYifJ6, 0.0f);
  numBytes += cIf_init(&cIf_vziYoy3K, false);
  numBytes += cIf_init(&cIf_XmnsnzEg, false);
  numBytes += cBinop_init(&cBinop_9uzbjY46, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_x7OXI6b6, 1, -1);
  numBytes += cVar_init_f(&cVar_acsrg6T9, 0.0f);
  numBytes += sVarf_init(&sVarf_Q4ey7pyx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7vorwxen, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HyjJ8O4i, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_74iFaBF1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_23av4EMO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oHGh5CZB, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_uBweunM3, 0.0f);
  numBytes += sVarf_init(&sVarf_670Lzilk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wEkPf3Zi, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NC1HmHvH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9ViDh31u, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_MANGLR::~Heavy_WSTD_MANGLR() {
  sEnv_free(&sEnv_nbunmxn0);
  sEnv_free(&sEnv_oXOfsHRh);
  sEnv_free(&sEnv_Wtw0GUeH);
  sEnv_free(&sEnv_DrObLSba);
}

HvTable *Heavy_WSTD_MANGLR::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_MANGLR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xE2DA4DC3: { // Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fKeWCIpK_sendMessage);
      break;
    }
    case 0xE42C892E: { // Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OQ9dvt8q_sendMessage);
      break;
    }
    case 0x677821DA: { // Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YlFZRXyo_sendMessage);
      break;
    }
    case 0xCB23DC60: { // Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8Acs77G2_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uaPIeLye_sendMessage);
      break;
    }
    case 0xD88E26F9: { // Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ROHy0QDD_sendMessage);
      break;
    }
    case 0x53F863DB: { // Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Smn1LcUm_sendMessage);
      break;
    }
    case 0xCF8296B9: { // 1001-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tBF9gqZh_sendMessage);
      break;
    }
    case 0x5F451395: { // 1021-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DOjfhsGp_sendMessage);
      break;
    }
    case 0xE57C8A1D: { // 1021-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rLgreRKT_sendMessage);
      break;
    }
    case 0x67279E1E: { // 1021-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_E2CnPw4S_sendMessage);
      break;
    }
    case 0x8CC7D86F: { // 1021-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YdbgW1jH_sendMessage);
      break;
    }
    case 0xA88C638E: { // 1021-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_a1rQ6Pka_sendMessage);
      break;
    }
    case 0x15406E9F: { // 1021-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BcUCxyIF_sendMessage);
      break;
    }
    case 0x3C30F4E8: { // 1139-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WT8fUvuN_sendMessage);
      break;
    }
    case 0xEF3938C5: { // 1139-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0PwMitDv_sendMessage);
      break;
    }
    case 0x416CCE3D: { // 1139-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9L3QVJzj_sendMessage);
      break;
    }
    case 0xA9746D8B: { // 1139-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2CsfgG9d_sendMessage);
      break;
    }
    case 0x8DCB26C5: { // 1139-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hWXLjUds_sendMessage);
      break;
    }
    case 0x6EC228E5: { // 1139-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RX2magDI_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3IUEhKcN_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_MANGLR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Crshr";
        info->hash = 0xE2DA4DC3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 1: {
        info->name = "Fldr";
        info->hash = 0xE42C892E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "Gain";
        info->hash = 0x677821DA;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -20.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Lmtr";
        info->hash = 0xCB23DC60;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 4: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 5: {
        info->name = "Smthr";
        info->hash = 0xD88E26F9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 6: {
        info->name = "Sqnc";
        info->hash = 0x53F863DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 7;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_MANGLR::cVar_NnFQC02Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_s6dZb2m7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_icek4v4e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_IlkgNkKt_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_IlkgNkKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_kFgP0wWc_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_kFgP0wWc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_GD16kUnS_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_GD16kUnS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rpktxyFI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RyBD3G1n_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_RyBD3G1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_53LhFUAy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_rpktxyFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_4yqQYskf_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_4yqQYskf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Qpf7h4dz_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_53LhFUAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_GDoI0cpb_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_GDoI0cpb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_2YlDXYnd_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Qpf7h4dz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Yf78NnL7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_2YlDXYnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VMhy3yb3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_PXhJ5RdN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pCOC6aGS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_TIYJj84S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mw8HFibN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_zOOKXITg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vimH59Sz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_PcMmMQ1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4qCrMEhM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_4xVD7IB9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vjpCEPIS_sendMessage);
  cMsg_ndlg7Oj6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_vjpCEPIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4xVD7IB9, 1, m, &cVar_4xVD7IB9_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_iT3esoXs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v9aTvFDC_sendMessage(_c, 0, m);
  cMsg_kvnBGoDu_sendMessage(_c, 0, m);
  cMsg_Ni2wpFgP_sendMessage(_c, 0, m);
  cMsg_Smdzmd5G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_8ivWCotc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MxcwchKi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_iQ4j9j7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R6AUOBmE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_FR9sOHX5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YbG6FC8O_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_91srT3WE_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cV3MphGf_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9F8oghn7_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vMHiwQSn_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NXrpTWdj_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cCast_YbG6FC8O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rXXVcCMZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_91srT3WE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8TumB9mk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_cV3MphGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Rn0QB1qt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_9F8oghn7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I5nupYE1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_vMHiwQSn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i2gfeYhi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_NXrpTWdj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ggUAHZLg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cIf_4FrwURaA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wHVdig7i_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_sZiGxnyK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_B4FY0Q05_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_kHmUn0m3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_PIfUZ1zV_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_PIfUZ1zV_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_1QdgwoWh, 1, m, &cDelay_1QdgwoWh_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ai5fCRcE_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_1QdgwoWh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1QdgwoWh, m);
  cIf_onMessage(_c, &Context(_c)->cIf_4FrwURaA, 0, m, &cIf_4FrwURaA_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_PIfUZ1zV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_1QdgwoWh, 0, m, &cDelay_1QdgwoWh_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ai5fCRcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1QdgwoWh, 0, m, &cDelay_1QdgwoWh_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_JvrftFSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zzAZl9sY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gQ12S7qJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Ti3g1X2s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_85pv7UMy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sErWSxiY_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_sErWSxiY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_kHmUn0m3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_85pv7UMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4FrwURaA, 1, m, &cIf_4FrwURaA_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_gQ12S7qJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sZiGxnyK, 0, m, &cIf_sZiGxnyK_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_zzAZl9sY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sZiGxnyK, 1, m, &cIf_sZiGxnyK_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_B4FY0Q05_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0WFl1CmR, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_wHVdig7i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0WFl1CmR, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_O7OTxCIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_duszED6g_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_dbuZTaPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2I1f9ozG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_koTcBoyV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_EXxcsd8U_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_EXxcsd8U_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_RYGnSiWY, 1, m, &cDelay_RYGnSiWY_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZBx1iYf5_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_RYGnSiWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RYGnSiWY, m);
  cIf_onMessage(_c, &Context(_c)->cIf_O7OTxCIg, 0, m, &cIf_O7OTxCIg_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_EXxcsd8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_RYGnSiWY, 0, m, &cDelay_RYGnSiWY_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ZBx1iYf5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RYGnSiWY, 0, m, &cDelay_RYGnSiWY_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_ou5QMgQ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jVXx1gWE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZWoV8ML1_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_KWXd3icg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Y7MP1XeI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zkfHV11R_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_zkfHV11R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_koTcBoyV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_Y7MP1XeI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_O7OTxCIg, 1, m, &cIf_O7OTxCIg_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_jVXx1gWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dbuZTaPo, 1, m, &cIf_dbuZTaPo_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ZWoV8ML1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dbuZTaPo, 0, m, &cIf_dbuZTaPo_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_2I1f9ozG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_huB7Y2WV, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_duszED6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_huB7Y2WV, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_vPRCj8EX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_URKSIGHD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_1x0MzRA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XyzVthUk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_zzjdFtcH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_7FtmDcbn_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_7FtmDcbn_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_2QTKQxeC, 1, m, &cDelay_2QTKQxeC_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SPO01iWe_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_2QTKQxeC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2QTKQxeC, m);
  cIf_onMessage(_c, &Context(_c)->cIf_vPRCj8EX, 0, m, &cIf_vPRCj8EX_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_7FtmDcbn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_2QTKQxeC, 0, m, &cDelay_2QTKQxeC_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_SPO01iWe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2QTKQxeC, 0, m, &cDelay_2QTKQxeC_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_uLU5rF4h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6i868CjP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pG1tvDXi_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_7TBu1XGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Stp8PyiP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BOOCJxgZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_BOOCJxgZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_zzjdFtcH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_Stp8PyiP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vPRCj8EX, 1, m, &cIf_vPRCj8EX_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_6i868CjP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1x0MzRA0, 1, m, &cIf_1x0MzRA0_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_pG1tvDXi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1x0MzRA0, 0, m, &cIf_1x0MzRA0_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_XyzVthUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SESCXPR5, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_URKSIGHD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SESCXPR5, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_mEp1tI3v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_25zEz9q7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_LqNyG4xI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Ctj8JusS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_84tMNWaX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_tBG4y3YW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_tBG4y3YW_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_sjzGsQyn, 1, m, &cDelay_sjzGsQyn_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lyGKc6Ar_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_sjzGsQyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sjzGsQyn, m);
  cIf_onMessage(_c, &Context(_c)->cIf_mEp1tI3v, 0, m, &cIf_mEp1tI3v_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_tBG4y3YW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_sjzGsQyn, 0, m, &cDelay_sjzGsQyn_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_lyGKc6Ar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_sjzGsQyn, 0, m, &cDelay_sjzGsQyn_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_AYavMkr4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T2sE2lVS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MrIsm6NU_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_7jGYvA5S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wwWkPd8J_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X0MoHDRt_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_X0MoHDRt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_84tMNWaX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_wwWkPd8J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mEp1tI3v, 1, m, &cIf_mEp1tI3v_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_MrIsm6NU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LqNyG4xI, 0, m, &cIf_LqNyG4xI_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_T2sE2lVS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LqNyG4xI, 1, m, &cIf_LqNyG4xI_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Ctj8JusS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dd3EDFDj, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_25zEz9q7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dd3EDFDj, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_5HEqktUh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vOuaVKyz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_67kiLj0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MyEMReJh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_ozdHqj4I_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_CZBQLczO_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_CZBQLczO_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_j1wVPa8b, 1, m, &cDelay_j1wVPa8b_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PpZnLG07_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_j1wVPa8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_j1wVPa8b, m);
  cIf_onMessage(_c, &Context(_c)->cIf_5HEqktUh, 0, m, &cIf_5HEqktUh_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_CZBQLczO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_j1wVPa8b, 0, m, &cDelay_j1wVPa8b_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_PpZnLG07_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_j1wVPa8b, 0, m, &cDelay_j1wVPa8b_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_e6o8cjgB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l3GXM8gE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LbTjgspe_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_AlzIC5D8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8bkHmESC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jlSl5quS_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_jlSl5quS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ozdHqj4I_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_8bkHmESC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5HEqktUh, 1, m, &cIf_5HEqktUh_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_l3GXM8gE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_67kiLj0T, 1, m, &cIf_67kiLj0T_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_LbTjgspe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_67kiLj0T, 0, m, &cIf_67kiLj0T_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_MyEMReJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SySItBN8, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_vOuaVKyz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SySItBN8, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_iMk6N7hF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QpOG7vZP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_w5nmsPau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uBshCC4e_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_vq9hBfB2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Ievp5dBp_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Ievp5dBp_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_1O0gjIOg, 1, m, &cDelay_1O0gjIOg_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vwX43GhM_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_1O0gjIOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1O0gjIOg, m);
  cIf_onMessage(_c, &Context(_c)->cIf_iMk6N7hF, 0, m, &cIf_iMk6N7hF_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Ievp5dBp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_1O0gjIOg, 0, m, &cDelay_1O0gjIOg_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_vwX43GhM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1O0gjIOg, 0, m, &cDelay_1O0gjIOg_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_mLlO0nvJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Z8TqSIi1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KCvhy9Ox_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_sYkD9Wav_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_agkbEJKf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9wOlcHyE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_9wOlcHyE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_vq9hBfB2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_agkbEJKf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iMk6N7hF, 1, m, &cIf_iMk6N7hF_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Z8TqSIi1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_w5nmsPau, 1, m, &cIf_w5nmsPau_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_KCvhy9Ox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_w5nmsPau, 0, m, &cIf_w5nmsPau_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_uBshCC4e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_E6Akevzs, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_QpOG7vZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_E6Akevzs, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_CbLIJLIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yLTlZUq2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_JXCwPef6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zCoutTDw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_LgWTM0SK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_zp08jBbd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_zp08jBbd_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Pz7q9O4h, 1, m, &cDelay_Pz7q9O4h_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x5T3UqU7_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_Pz7q9O4h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Pz7q9O4h, m);
  cIf_onMessage(_c, &Context(_c)->cIf_CbLIJLIN, 0, m, &cIf_CbLIJLIN_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_zp08jBbd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Pz7q9O4h, 0, m, &cDelay_Pz7q9O4h_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_x5T3UqU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Pz7q9O4h, 0, m, &cDelay_Pz7q9O4h_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_xeViEALV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d6TqPEcM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6BfVhWzg_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_tLT7VPkp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D4WGdGq3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_91wIpb3j_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_91wIpb3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_LgWTM0SK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_D4WGdGq3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CbLIJLIN, 1, m, &cIf_CbLIJLIN_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_d6TqPEcM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JXCwPef6, 1, m, &cIf_JXCwPef6_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_6BfVhWzg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JXCwPef6, 0, m, &cIf_JXCwPef6_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_zCoutTDw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lEIo5vcb, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_yLTlZUq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lEIo5vcb, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_8QxMlKnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DZpBtdXO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_5h26AVb8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PugpqtVu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_RUAPoK4y_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_aiVg5yMP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_aiVg5yMP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Dfd8NzgJ, 1, m, &cDelay_Dfd8NzgJ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ajbXkNgO_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_Dfd8NzgJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Dfd8NzgJ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_8QxMlKnF, 0, m, &cIf_8QxMlKnF_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_aiVg5yMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Dfd8NzgJ, 0, m, &cDelay_Dfd8NzgJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ajbXkNgO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Dfd8NzgJ, 0, m, &cDelay_Dfd8NzgJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_vBsTb81X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_G7CMTlHh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QIR7vXqP_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_UA8BGfGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NhS7ZwVV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZH2tGusQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ZH2tGusQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_RUAPoK4y_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_NhS7ZwVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8QxMlKnF, 1, m, &cIf_8QxMlKnF_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_QIR7vXqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5h26AVb8, 0, m, &cIf_5h26AVb8_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_G7CMTlHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5h26AVb8, 1, m, &cIf_5h26AVb8_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_PugpqtVu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xO1ntkR7, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_DZpBtdXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xO1ntkR7, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_rocIBvyQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XyizBdPE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_y7VvRN5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_25NBJePX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_U1dEM2EE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_IXh1pdjR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_IXh1pdjR_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_oMeEXHFl, 1, m, &cDelay_oMeEXHFl_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qPiCbWNn_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_oMeEXHFl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oMeEXHFl, m);
  cIf_onMessage(_c, &Context(_c)->cIf_rocIBvyQ, 0, m, &cIf_rocIBvyQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_IXh1pdjR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_oMeEXHFl, 0, m, &cDelay_oMeEXHFl_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_qPiCbWNn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oMeEXHFl, 0, m, &cDelay_oMeEXHFl_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_uL5Gy7f2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rSp9sQBx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MmDbFa8R_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_YozpetjR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_f5EHoALv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bWY6jwHb_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_bWY6jwHb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_U1dEM2EE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_f5EHoALv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rocIBvyQ, 1, m, &cIf_rocIBvyQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_MmDbFa8R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_y7VvRN5B, 0, m, &cIf_y7VvRN5B_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_rSp9sQBx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_y7VvRN5B, 1, m, &cIf_y7VvRN5B_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_25NBJePX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fWC4fTQn, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_XyizBdPE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fWC4fTQn, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_lOXCPCaB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Br2DHpqj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_q8xWi110_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_t2FMTbIB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_ulkAWo9e_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_lhUYQzKn_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_lhUYQzKn_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_v0t6esvJ, 1, m, &cDelay_v0t6esvJ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yXnREevl_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_v0t6esvJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_v0t6esvJ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_lOXCPCaB, 0, m, &cIf_lOXCPCaB_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_lhUYQzKn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_v0t6esvJ, 0, m, &cDelay_v0t6esvJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_yXnREevl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_v0t6esvJ, 0, m, &cDelay_v0t6esvJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Hreo9X9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_liXPQ98X_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aIg02H4b_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Ji9V4p3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sPZ1IhgE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TSsOMuja_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_TSsOMuja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ulkAWo9e_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_sPZ1IhgE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lOXCPCaB, 1, m, &cIf_lOXCPCaB_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_liXPQ98X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_q8xWi110, 1, m, &cIf_q8xWi110_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_aIg02H4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_q8xWi110, 0, m, &cIf_q8xWi110_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_t2FMTbIB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WqlcTdqD, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Br2DHpqj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WqlcTdqD, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_R2iSSuzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PINdUjtq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_A3BouYLt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XrEmndix_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_XRUJPdyk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_goJ7Xg8I_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_goJ7Xg8I_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Oy2RDiNP, 1, m, &cDelay_Oy2RDiNP_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tKvBZ02Q_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_Oy2RDiNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Oy2RDiNP, m);
  cIf_onMessage(_c, &Context(_c)->cIf_R2iSSuzE, 0, m, &cIf_R2iSSuzE_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_goJ7Xg8I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Oy2RDiNP, 0, m, &cDelay_Oy2RDiNP_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_tKvBZ02Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Oy2RDiNP, 0, m, &cDelay_Oy2RDiNP_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_u69AzDpK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oJ6TtzsB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2q7N9cje_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_KKd1wt04_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zfJU0ppc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6EamCHjW_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_zfJU0ppc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_R2iSSuzE, 1, m, &cIf_R2iSSuzE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_6EamCHjW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_XRUJPdyk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_2q7N9cje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_A3BouYLt, 0, m, &cIf_A3BouYLt_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_oJ6TtzsB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_A3BouYLt, 1, m, &cIf_A3BouYLt_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_XrEmndix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Rn0Xkg1y, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_PINdUjtq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Rn0Xkg1y, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_26vMdN26_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NVitKE7c_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_Bg4HKnbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gLkfa3ix_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_gWZpELYh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_dPrDUiNP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_dPrDUiNP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wwnLutbp, 1, m, &cDelay_wwnLutbp_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6905fz7c_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_wwnLutbp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wwnLutbp, m);
  cIf_onMessage(_c, &Context(_c)->cIf_26vMdN26, 0, m, &cIf_26vMdN26_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_dPrDUiNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wwnLutbp, 0, m, &cDelay_wwnLutbp_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_6905fz7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wwnLutbp, 0, m, &cDelay_wwnLutbp_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_0DLnL5gD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wCOMLvFd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V5qDvfIe_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_meL3mylg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gKPqOgLF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HWILnghQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_gKPqOgLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_26vMdN26, 1, m, &cIf_26vMdN26_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_HWILnghQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_gWZpELYh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_wCOMLvFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Bg4HKnbl, 1, m, &cIf_Bg4HKnbl_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_V5qDvfIe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Bg4HKnbl, 0, m, &cIf_Bg4HKnbl_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_gLkfa3ix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rp3wD9rq, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_NVitKE7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rp3wD9rq, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_rXXVcCMZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_1LqDjRli_sendMessage(_c, 0, m);
  cMsg_a4349JL3_sendMessage(_c, 0, m);
  cMsg_kcrK5Q0v_sendMessage(_c, 0, m);
  cMsg_ksDpRkHO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_8TumB9mk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_1LqDjRli_sendMessage(_c, 0, m);
  cMsg_839vi551_sendMessage(_c, 0, m);
  cMsg_PabEN92s_sendMessage(_c, 0, m);
  cMsg_0HmAL4Kc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Rn0QB1qt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_dtZJXUT3_sendMessage(_c, 0, m);
  cMsg_839vi551_sendMessage(_c, 0, m);
  cMsg_ksDpRkHO_sendMessage(_c, 0, m);
  cMsg_lTa7JaGF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_I5nupYE1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_dtZJXUT3_sendMessage(_c, 0, m);
  cMsg_dqeGG2kp_sendMessage(_c, 0, m);
  cMsg_kcrK5Q0v_sendMessage(_c, 0, m);
  cMsg_M5cNxMfT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_i2gfeYhi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_r65DbyQx_sendMessage(_c, 0, m);
  cMsg_0HmAL4Kc_sendMessage(_c, 0, m);
  cMsg_Zwk1gywR_sendMessage(_c, 0, m);
  cMsg_kcrK5Q0v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_ggUAHZLg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_r65DbyQx_sendMessage(_c, 0, m);
  cMsg_M5cNxMfT_sendMessage(_c, 0, m);
  cMsg_839vi551_sendMessage(_c, 0, m);
  cMsg_XDjp6tSf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_bBmw7O9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Ti3g1X2s_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JvrftFSG_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_9CYYDLVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Ti3g1X2s_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JvrftFSG_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ryXj6b2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KWXd3icg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ou5QMgQ5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_NxnhevJD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KWXd3icg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ou5QMgQ5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_AELCY57H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7TBu1XGf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uLU5rF4h_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Vn0groAE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7TBu1XGf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uLU5rF4h_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1LqDjRli_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_bBmw7O9Y_sendMessage(_c, 0, m);
  cMsg_NxnhevJD_sendMessage(_c, 0, m);
  cMsg_Vn0groAE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_dtZJXUT3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_9CYYDLVY_sendMessage(_c, 0, m);
  cMsg_ryXj6b2v_sendMessage(_c, 0, m);
  cMsg_Vn0groAE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_r65DbyQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_9CYYDLVY_sendMessage(_c, 0, m);
  cMsg_NxnhevJD_sendMessage(_c, 0, m);
  cMsg_AELCY57H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_8J19anby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7jGYvA5S_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AYavMkr4_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1oceMToi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7jGYvA5S_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AYavMkr4_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_55ZmmHpo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_AlzIC5D8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_e6o8cjgB_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_aRVwaE3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_AlzIC5D8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_e6o8cjgB_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_LQu4HF8y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sYkD9Wav_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_mLlO0nvJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_uXsDTWly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sYkD9Wav_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_mLlO0nvJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_839vi551_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_1oceMToi_sendMessage(_c, 0, m);
  cMsg_aRVwaE3d_sendMessage(_c, 0, m);
  cMsg_uXsDTWly_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_a4349JL3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_1oceMToi_sendMessage(_c, 0, m);
  cMsg_55ZmmHpo_sendMessage(_c, 0, m);
  cMsg_LQu4HF8y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_dqeGG2kp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_8J19anby_sendMessage(_c, 0, m);
  cMsg_aRVwaE3d_sendMessage(_c, 0, m);
  cMsg_LQu4HF8y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_arNlBEtw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Ji9V4p3u_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Hreo9X9b_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_mudGYInl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Ji9V4p3u_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Hreo9X9b_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_iX2Mtv09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KKd1wt04_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_u69AzDpK_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_urH0fl59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KKd1wt04_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_u69AzDpK_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_xvuezEUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_meL3mylg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0DLnL5gD_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_nL4Bxbh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_meL3mylg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0DLnL5gD_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_M5cNxMfT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_arNlBEtw_sendMessage(_c, 0, m);
  cMsg_urH0fl59_sendMessage(_c, 0, m);
  cMsg_nL4Bxbh0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_0HmAL4Kc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_mudGYInl_sendMessage(_c, 0, m);
  cMsg_iX2Mtv09_sendMessage(_c, 0, m);
  cMsg_nL4Bxbh0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_ksDpRkHO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_mudGYInl_sendMessage(_c, 0, m);
  cMsg_urH0fl59_sendMessage(_c, 0, m);
  cMsg_xvuezEUk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_vNNjAvdX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tLT7VPkp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xeViEALV_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_zE8E1jZk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tLT7VPkp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xeViEALV_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ul2GERqk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_UA8BGfGD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vBsTb81X_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_6TyLqb4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_UA8BGfGD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vBsTb81X_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_sG6YlsWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_YozpetjR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uL5Gy7f2_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_BlSrr41e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_YozpetjR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uL5Gy7f2_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_kcrK5Q0v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_zE8E1jZk_sendMessage(_c, 0, m);
  cMsg_6TyLqb4F_sendMessage(_c, 0, m);
  cMsg_BlSrr41e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_PabEN92s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_zE8E1jZk_sendMessage(_c, 0, m);
  cMsg_ul2GERqk_sendMessage(_c, 0, m);
  cMsg_sG6YlsWS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_XDjp6tSf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_vNNjAvdX_sendMessage(_c, 0, m);
  cMsg_ul2GERqk_sendMessage(_c, 0, m);
  cMsg_BlSrr41e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Zwk1gywR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_8J19anby_sendMessage(_c, 0, m);
  cMsg_55ZmmHpo_sendMessage(_c, 0, m);
  cMsg_uXsDTWly_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_lTa7JaGF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_vNNjAvdX_sendMessage(_c, 0, m);
  cMsg_6TyLqb4F_sendMessage(_c, 0, m);
  cMsg_sG6YlsWS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_DvUsMCNE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8bNGln67_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_r5EVPaKw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Xf3xyJHX, 0, m, &cSlice_Xf3xyJHX_sendMessage);
      break;
    }
    default: {
      cSwitchcase_XVw4fp9R_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_Xf3xyJHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_vx0JALbW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_vx0JALbW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_sorhhRPl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vx0JALbW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_vx0JALbW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rLgreRKT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_kySda359_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UhbQbdMI, 0, m, &cSlice_UhbQbdMI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_lfLfm8pN_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_UhbQbdMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_b7kpb7st_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_b7kpb7st_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_EColGcM4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_b7kpb7st_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_b7kpb7st_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BcUCxyIF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_lfLfm8pN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Pyk85ZvW, 0, m, &cSlice_Pyk85ZvW_sendMessage);
      break;
    }
    default: {
      cSwitchcase_r5EVPaKw_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_Pyk85ZvW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_oxIFhCT4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_oxIFhCT4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_3Psh4dKO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oxIFhCT4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_oxIFhCT4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DOjfhsGp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_XVw4fp9R_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_B0kWcHiE, 0, m, &cSlice_B0kWcHiE_sendMessage);
      break;
    }
    default: {
      cSwitchcase_iJP1oWSc_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_B0kWcHiE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_bjulhATA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_bjulhATA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_CLjfhHWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bjulhATA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_bjulhATA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_a1rQ6Pka_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_iJP1oWSc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_P9Ml3uWc, 0, m, &cSlice_P9Ml3uWc_sendMessage);
      break;
    }
    default: {
      cSwitchcase_wkjx03wu_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_P9Ml3uWc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jXpH5KgA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jXpH5KgA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_Szmwv7FY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jXpH5KgA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_jXpH5KgA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YdbgW1jH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_K3xjtQbC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_eI1N496k_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_eI1N496k_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_6PVKzSkP, 1, m, &cDelay_6PVKzSkP_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iR3m3frS_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_6PVKzSkP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6PVKzSkP, m);
  cMsg_75HgF57O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_eI1N496k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_6PVKzSkP, 0, m, &cDelay_6PVKzSkP_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_iR3m3frS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6PVKzSkP, 0, m, &cDelay_6PVKzSkP_sendMessage);
}

void Heavy_WSTD_MANGLR::cVar_SG0gLPYX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B3TXEzNz, HV_BINOP_SUBTRACT, 0, m, &cBinop_B3TXEzNz_sendMessage);
}

void Heavy_WSTD_MANGLR::cIf_cc4fQHNV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PiZWXO7Z_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_3pKxOdiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PiZWXO7Z_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::sEnv_nbunmxn0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SG0gLPYX, 0, m, &cVar_SG0gLPYX_sendMessage);
}

void Heavy_WSTD_MANGLR::sEnv_oXOfsHRh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lKgVwgB5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_J0Upq10n_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AlM6T6rA_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_B3TXEzNz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oqSxCB5J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_oqSxCB5J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_7xY2XvCL_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_7xY2XvCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_yooeLviO_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_UdS6uvn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8UGVW33H_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YjBMhJYc_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_YjBMhJYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_syS86LDW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_8UGVW33H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cc4fQHNV, 1, m, &cIf_cc4fQHNV_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_UCneoRUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3pKxOdiT, 1, m, &cIf_3pKxOdiT_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_syS86LDW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_cc4fQHNV, 0, m, &cIf_cc4fQHNV_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_yooeLviO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3pKxOdiT, 0, m, &cIf_3pKxOdiT_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_lKgVwgB5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_MANGLR::cCast_J0Upq10n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B3TXEzNz, HV_BINOP_SUBTRACT, 1, m, &cBinop_B3TXEzNz_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_AlM6T6rA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SG0gLPYX, 0, m, &cVar_SG0gLPYX_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_PiZWXO7Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_f4ctMpoG, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSwitchcase_wkjx03wu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_bKrq6NIf, 0, m, &cSlice_bKrq6NIf_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_bKrq6NIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_4eJuEi1P_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_4eJuEi1P_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_aA5vH6l1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4eJuEi1P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_4eJuEi1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_E2CnPw4S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_MxcwchKi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9A5WEpUm, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_R6AUOBmE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DeCdipZ6, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_RxvjtDjF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iQ4j9j7j, 0, m, &cVar_iQ4j9j7j_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_8bNGln67_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iF0MyzzS, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_oSnpOx8E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_polr6H6a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_M852Uu8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_K3xjtQbC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_75HgF57O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gCoVXxsJ, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_polr6H6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gCoVXxsJ, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_2aZg1XPn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_nH4Zcl3C_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_nH4Zcl3C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xm6Uc1oG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_xm6Uc1oG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ir7HPw0m, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cVar_NacoAsBN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xAzfaPD2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_c5mf1clt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xpbk5IWc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_sjCA0yp4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GlO1ujHO_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6tmSJdrp_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r8u7pMYE_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CkLbDwQw_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fnKo8X35_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E50JmW2r_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cCast_GlO1ujHO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0Jo46sj4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_6tmSJdrp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f1gBBad7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_r8u7pMYE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dzBs56fB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_CkLbDwQw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eVg0bZze_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_fnKo8X35_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n1oMQ1or_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_E50JmW2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tDgIqYIc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cIf_63CqJSRo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TTO5X7sV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_wfG96rBe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_j9eYwpFI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_n9F8M3s9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_KHdfZsjj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_KHdfZsjj_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_yFRNNXWF, 1, m, &cDelay_yFRNNXWF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dCJPwJ5v_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_yFRNNXWF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yFRNNXWF, m);
  cIf_onMessage(_c, &Context(_c)->cIf_63CqJSRo, 0, m, &cIf_63CqJSRo_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_KHdfZsjj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_yFRNNXWF, 0, m, &cDelay_yFRNNXWF_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_dCJPwJ5v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_yFRNNXWF, 0, m, &cDelay_yFRNNXWF_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_uM54dqKo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SGMD1tdE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_08pOpgd8_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_OQYphrmn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EyhP3wvd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NFfpCgz2_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_NFfpCgz2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_n9F8M3s9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_EyhP3wvd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_63CqJSRo, 1, m, &cIf_63CqJSRo_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_08pOpgd8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wfG96rBe, 0, m, &cIf_wfG96rBe_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_SGMD1tdE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wfG96rBe, 1, m, &cIf_wfG96rBe_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_j9eYwpFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VtpwnTD0, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_TTO5X7sV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VtpwnTD0, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_KXDfinBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2g0spmuu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_T2O6p5S7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dzCDdbrq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_iqvHhXIl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_712XIgnI_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_712XIgnI_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_p9ldyWyj, 1, m, &cDelay_p9ldyWyj_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Yj2kx1Xm_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_p9ldyWyj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_p9ldyWyj, m);
  cIf_onMessage(_c, &Context(_c)->cIf_KXDfinBq, 0, m, &cIf_KXDfinBq_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_712XIgnI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_p9ldyWyj, 0, m, &cDelay_p9ldyWyj_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Yj2kx1Xm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_p9ldyWyj, 0, m, &cDelay_p9ldyWyj_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_fNW1A7nh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Uctwe5Ox_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0DuygGJh_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Ract6ZBv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jv1ehwkq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j8UUKzwg_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_j8UUKzwg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_iqvHhXIl_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_jv1ehwkq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KXDfinBq, 1, m, &cIf_KXDfinBq_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_0DuygGJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_T2O6p5S7, 0, m, &cIf_T2O6p5S7_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Uctwe5Ox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_T2O6p5S7, 1, m, &cIf_T2O6p5S7_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_dzCDdbrq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HCVn7SlN, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_2g0spmuu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HCVn7SlN, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_WKMfRjQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0WBPKusB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_mZXYjJtF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_GFRafgWm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_55cbSPXA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_AduB2KXg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_AduB2KXg_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_vpFwQZI7, 1, m, &cDelay_vpFwQZI7_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RPGOfnXq_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_vpFwQZI7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vpFwQZI7, m);
  cIf_onMessage(_c, &Context(_c)->cIf_WKMfRjQS, 0, m, &cIf_WKMfRjQS_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_AduB2KXg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vpFwQZI7, 0, m, &cDelay_vpFwQZI7_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_RPGOfnXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vpFwQZI7, 0, m, &cDelay_vpFwQZI7_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Yl1GVSev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qRHVWnUp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v8NVDy5M_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_JVUP5YRf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_42eS06yS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HyVS3ffc_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_HyVS3ffc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_55cbSPXA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_42eS06yS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WKMfRjQS, 1, m, &cIf_WKMfRjQS_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_qRHVWnUp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mZXYjJtF, 1, m, &cIf_mZXYjJtF_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_v8NVDy5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mZXYjJtF, 0, m, &cIf_mZXYjJtF_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_GFRafgWm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XXb9kCR5, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_0WBPKusB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XXb9kCR5, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_cb8uoENz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8AyuJbko_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_hR05TLeq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_v8yMhriO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_tXqyN19w_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_SfZPIvtg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_SfZPIvtg_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_mWst5TOm, 1, m, &cDelay_mWst5TOm_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_keaJELY4_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_mWst5TOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mWst5TOm, m);
  cIf_onMessage(_c, &Context(_c)->cIf_cb8uoENz, 0, m, &cIf_cb8uoENz_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_SfZPIvtg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_mWst5TOm, 0, m, &cDelay_mWst5TOm_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_keaJELY4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mWst5TOm, 0, m, &cDelay_mWst5TOm_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_rzkjvcPB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xLvnvFto_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DL9Mfixe_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_J3Hdn0Is_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_54UFl05A_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_haSFLrGB_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_54UFl05A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cb8uoENz, 1, m, &cIf_cb8uoENz_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_haSFLrGB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tXqyN19w_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_DL9Mfixe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hR05TLeq, 0, m, &cIf_hR05TLeq_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_xLvnvFto_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hR05TLeq, 1, m, &cIf_hR05TLeq_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_v8yMhriO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gGv292lZ, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_8AyuJbko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gGv292lZ, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_bZ2MlZ4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BrBrkfz4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_KcTcbym9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VHI3D8It_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_YRCK4LNb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_kq3ZTdvn_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_kq3ZTdvn_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Q3jVnUMO, 1, m, &cDelay_Q3jVnUMO_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AtEKCmus_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_Q3jVnUMO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Q3jVnUMO, m);
  cIf_onMessage(_c, &Context(_c)->cIf_bZ2MlZ4n, 0, m, &cIf_bZ2MlZ4n_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_kq3ZTdvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q3jVnUMO, 0, m, &cDelay_Q3jVnUMO_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_AtEKCmus_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q3jVnUMO, 0, m, &cDelay_Q3jVnUMO_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_i6dou7rj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kNJIgRys_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_urCOWPK7_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_HJzeqYhj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_G1Il6uNP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dVXWlXH8_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_dVXWlXH8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_YRCK4LNb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_G1Il6uNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bZ2MlZ4n, 1, m, &cIf_bZ2MlZ4n_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_kNJIgRys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KcTcbym9, 1, m, &cIf_KcTcbym9_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_urCOWPK7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KcTcbym9, 0, m, &cIf_KcTcbym9_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_VHI3D8It_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BPBtlzqv, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_BrBrkfz4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BPBtlzqv, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_X9HGMk54_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HvWTcCVr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_OOxZi3LQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UlL2GNS8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_8QcEds4u_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_THMKnwWR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_THMKnwWR_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_CEnsTTwN, 1, m, &cDelay_CEnsTTwN_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vxvQKA19_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_CEnsTTwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CEnsTTwN, m);
  cIf_onMessage(_c, &Context(_c)->cIf_X9HGMk54, 0, m, &cIf_X9HGMk54_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_THMKnwWR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_CEnsTTwN, 0, m, &cDelay_CEnsTTwN_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_vxvQKA19_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CEnsTTwN, 0, m, &cDelay_CEnsTTwN_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_TX4wV6lp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UoE8epMQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FnXYU2CK_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_4Kn133Se_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OfLb0kAh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0NQh37Q9_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_OfLb0kAh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_X9HGMk54, 1, m, &cIf_X9HGMk54_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_0NQh37Q9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_8QcEds4u_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_FnXYU2CK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OOxZi3LQ, 0, m, &cIf_OOxZi3LQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_UoE8epMQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OOxZi3LQ, 1, m, &cIf_OOxZi3LQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_UlL2GNS8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FNnbHw25, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_HvWTcCVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FNnbHw25, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_s5LEhhsh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ZAOKMxEP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_BkUgpApd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ed5Ir7ew_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_JqVk6b9O_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_BP2RI16r_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_BP2RI16r_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_hdeMJuxE, 1, m, &cDelay_hdeMJuxE_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ua2q5sIC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_hdeMJuxE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hdeMJuxE, m);
  cIf_onMessage(_c, &Context(_c)->cIf_s5LEhhsh, 0, m, &cIf_s5LEhhsh_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_BP2RI16r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_hdeMJuxE, 0, m, &cDelay_hdeMJuxE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ua2q5sIC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hdeMJuxE, 0, m, &cDelay_hdeMJuxE_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Bnintw71_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TmBKqa0E_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xzri9dID_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_MQN2V0Tt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gACtNyF2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iyoDE3cW_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_iyoDE3cW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JqVk6b9O_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_gACtNyF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_s5LEhhsh, 1, m, &cIf_s5LEhhsh_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_TmBKqa0E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BkUgpApd, 1, m, &cIf_BkUgpApd_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_xzri9dID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BkUgpApd, 0, m, &cIf_BkUgpApd_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ed5Ir7ew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5LJkXRmk, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_ZAOKMxEP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5LJkXRmk, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_s4H3CBLu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uuyARd0R_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_wIaCbJGB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_O0Nwp8UJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_uaQ1YQcp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_M7D1tNIh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_M7D1tNIh_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_QilEbcwx, 1, m, &cDelay_QilEbcwx_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FnCaMiAE_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_QilEbcwx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_QilEbcwx, m);
  cIf_onMessage(_c, &Context(_c)->cIf_s4H3CBLu, 0, m, &cIf_s4H3CBLu_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_M7D1tNIh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_QilEbcwx, 0, m, &cDelay_QilEbcwx_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_FnCaMiAE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_QilEbcwx, 0, m, &cDelay_QilEbcwx_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_zLZrkvtq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_j2WtvqB7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FQHnX6J6_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_hzPxIhTS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eEY5Ivxv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gp9GNCc1_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_gp9GNCc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_uaQ1YQcp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_eEY5Ivxv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_s4H3CBLu, 1, m, &cIf_s4H3CBLu_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_j2WtvqB7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wIaCbJGB, 1, m, &cIf_wIaCbJGB_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_FQHnX6J6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wIaCbJGB, 0, m, &cIf_wIaCbJGB_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_O0Nwp8UJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6NVw6gWs, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_uuyARd0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6NVw6gWs, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_caN2zBZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_kgEa2XQZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_A1xEXqXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vVH9CnqO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_MYXVxmLh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_57F5DWfc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_57F5DWfc_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wgsh0t8Q, 1, m, &cDelay_wgsh0t8Q_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CkdeAcgr_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_wgsh0t8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wgsh0t8Q, m);
  cIf_onMessage(_c, &Context(_c)->cIf_caN2zBZR, 0, m, &cIf_caN2zBZR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_57F5DWfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wgsh0t8Q, 0, m, &cDelay_wgsh0t8Q_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_CkdeAcgr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wgsh0t8Q, 0, m, &cDelay_wgsh0t8Q_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_LdJZCSFU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RJYWxUMF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PqYGTOGy_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_W0tl2A2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mryXmkfi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_scgRLynG_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_scgRLynG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_MYXVxmLh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_mryXmkfi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_caN2zBZR, 1, m, &cIf_caN2zBZR_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_PqYGTOGy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_A1xEXqXZ, 0, m, &cIf_A1xEXqXZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_RJYWxUMF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_A1xEXqXZ, 1, m, &cIf_A1xEXqXZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_vVH9CnqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_btTEoo8f, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_kgEa2XQZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_btTEoo8f, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_Y1LCn2yM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RG1JeNZg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_gayfFHfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_T3siChZV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_UkzHl7Ms_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_doRChkTW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_doRChkTW_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Oy73Lovb, 1, m, &cDelay_Oy73Lovb_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dnwg8Fh1_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_Oy73Lovb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Oy73Lovb, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Y1LCn2yM, 0, m, &cIf_Y1LCn2yM_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_doRChkTW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Oy73Lovb, 0, m, &cDelay_Oy73Lovb_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_dnwg8Fh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Oy73Lovb, 0, m, &cDelay_Oy73Lovb_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_pyC877Sq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_He7KC9ey_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N2Z4sQY1_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Ljn8jdrR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9o1gU7of_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Xv0rEWpa_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_9o1gU7of_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Y1LCn2yM, 1, m, &cIf_Y1LCn2yM_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Xv0rEWpa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_UkzHl7Ms_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_He7KC9ey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gayfFHfs, 1, m, &cIf_gayfFHfs_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_N2Z4sQY1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gayfFHfs, 0, m, &cIf_gayfFHfs_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_T3siChZV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1qO2CIPA, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_RG1JeNZg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1qO2CIPA, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_WMnAeGSk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_L9b9rHau_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_nxdImuAc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_CuDcpD7V_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_8FT6JpgZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_hIVRgDmL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_hIVRgDmL_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wdyIgDVP, 1, m, &cDelay_wdyIgDVP_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xP6zMj2G_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_wdyIgDVP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wdyIgDVP, m);
  cIf_onMessage(_c, &Context(_c)->cIf_WMnAeGSk, 0, m, &cIf_WMnAeGSk_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_hIVRgDmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wdyIgDVP, 0, m, &cDelay_wdyIgDVP_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_xP6zMj2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wdyIgDVP, 0, m, &cDelay_wdyIgDVP_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Jh7VyYYn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9G6Qt1UU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h88KgJJr_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_sE4FmMvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HDb1zruD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0iBPfV0G_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_0iBPfV0G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_8FT6JpgZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_HDb1zruD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WMnAeGSk, 1, m, &cIf_WMnAeGSk_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_h88KgJJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nxdImuAc, 0, m, &cIf_nxdImuAc_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_9G6Qt1UU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nxdImuAc, 1, m, &cIf_nxdImuAc_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_CuDcpD7V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lwFsnvKi, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_L9b9rHau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lwFsnvKi, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_CJNvHvpU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_iyoWY1yH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_hWqxUOJU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aYBJhdf7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_VIsqhEBd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_c1XCuifU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_c1XCuifU_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_qpuLm9Qd, 1, m, &cDelay_qpuLm9Qd_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7SzAXmlg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_qpuLm9Qd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qpuLm9Qd, m);
  cIf_onMessage(_c, &Context(_c)->cIf_CJNvHvpU, 0, m, &cIf_CJNvHvpU_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_c1XCuifU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_qpuLm9Qd, 0, m, &cDelay_qpuLm9Qd_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_7SzAXmlg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_qpuLm9Qd, 0, m, &cDelay_qpuLm9Qd_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_s5KL6o9O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_suZNmMkD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IdAQ9dTU_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_JGg8GsiK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qo132hVq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4qCPehQF_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_4qCPehQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_VIsqhEBd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_qo132hVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CJNvHvpU, 1, m, &cIf_CJNvHvpU_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_IdAQ9dTU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hWqxUOJU, 0, m, &cIf_hWqxUOJU_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_suZNmMkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hWqxUOJU, 1, m, &cIf_hWqxUOJU_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_aYBJhdf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DdMLqQ1n, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_iyoWY1yH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DdMLqQ1n, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_0Jo46sj4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_orhtrUnE_sendMessage(_c, 0, m);
  cMsg_pl7ogU0b_sendMessage(_c, 0, m);
  cMsg_ge7oGx4w_sendMessage(_c, 0, m);
  cMsg_f8AdWTRl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_f1gBBad7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_orhtrUnE_sendMessage(_c, 0, m);
  cMsg_9JNHti8Z_sendMessage(_c, 0, m);
  cMsg_RYfL0apr_sendMessage(_c, 0, m);
  cMsg_8dQRTJ0v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_dzBs56fB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_40nU8DxY_sendMessage(_c, 0, m);
  cMsg_9JNHti8Z_sendMessage(_c, 0, m);
  cMsg_f8AdWTRl_sendMessage(_c, 0, m);
  cMsg_zETkiTAq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_eVg0bZze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_40nU8DxY_sendMessage(_c, 0, m);
  cMsg_Ynbqdx7C_sendMessage(_c, 0, m);
  cMsg_ge7oGx4w_sendMessage(_c, 0, m);
  cMsg_i7PrLJj7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_n1oMQ1or_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_tgP0Iez6_sendMessage(_c, 0, m);
  cMsg_8dQRTJ0v_sendMessage(_c, 0, m);
  cMsg_dof2096m_sendMessage(_c, 0, m);
  cMsg_ge7oGx4w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_tDgIqYIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_tgP0Iez6_sendMessage(_c, 0, m);
  cMsg_i7PrLJj7_sendMessage(_c, 0, m);
  cMsg_9JNHti8Z_sendMessage(_c, 0, m);
  cMsg_QowWabDp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_6A12FuFw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_OQYphrmn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uM54dqKo_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ymYyWxoX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_OQYphrmn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uM54dqKo_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_MxCU5hVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Ract6ZBv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fNW1A7nh_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_jBOQbKTG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Ract6ZBv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fNW1A7nh_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Ikh8h6DD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_JVUP5YRf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Yl1GVSev_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_zB4zZ2Cn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_JVUP5YRf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Yl1GVSev_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_orhtrUnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_6A12FuFw_sendMessage(_c, 0, m);
  cMsg_jBOQbKTG_sendMessage(_c, 0, m);
  cMsg_zB4zZ2Cn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_40nU8DxY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_ymYyWxoX_sendMessage(_c, 0, m);
  cMsg_MxCU5hVQ_sendMessage(_c, 0, m);
  cMsg_zB4zZ2Cn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_tgP0Iez6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_ymYyWxoX_sendMessage(_c, 0, m);
  cMsg_jBOQbKTG_sendMessage(_c, 0, m);
  cMsg_Ikh8h6DD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Pe5JM6yV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_J3Hdn0Is_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rzkjvcPB_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_iQrt90bR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_J3Hdn0Is_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rzkjvcPB_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_xkWh7DQO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HJzeqYhj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_i6dou7rj_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_pPk5p4Fw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HJzeqYhj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_i6dou7rj_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Bt6I8DDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_4Kn133Se_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TX4wV6lp_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_8NXIGyFk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_4Kn133Se_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TX4wV6lp_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_9JNHti8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_iQrt90bR_sendMessage(_c, 0, m);
  cMsg_pPk5p4Fw_sendMessage(_c, 0, m);
  cMsg_8NXIGyFk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_pl7ogU0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_iQrt90bR_sendMessage(_c, 0, m);
  cMsg_xkWh7DQO_sendMessage(_c, 0, m);
  cMsg_Bt6I8DDp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Ynbqdx7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_Pe5JM6yV_sendMessage(_c, 0, m);
  cMsg_pPk5p4Fw_sendMessage(_c, 0, m);
  cMsg_Bt6I8DDp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_opATxNLG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Ljn8jdrR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pyC877Sq_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_FQ8WKO9T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Ljn8jdrR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pyC877Sq_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_zNGOKbmk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sE4FmMvZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Jh7VyYYn_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_N7ZSjayR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sE4FmMvZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Jh7VyYYn_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_pIk9Ynjs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_JGg8GsiK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_s5KL6o9O_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_KB5qWCMw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_JGg8GsiK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_s5KL6o9O_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_i7PrLJj7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_opATxNLG_sendMessage(_c, 0, m);
  cMsg_N7ZSjayR_sendMessage(_c, 0, m);
  cMsg_KB5qWCMw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_8dQRTJ0v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_FQ8WKO9T_sendMessage(_c, 0, m);
  cMsg_zNGOKbmk_sendMessage(_c, 0, m);
  cMsg_KB5qWCMw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_f8AdWTRl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_FQ8WKO9T_sendMessage(_c, 0, m);
  cMsg_N7ZSjayR_sendMessage(_c, 0, m);
  cMsg_pIk9Ynjs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_3NLjbXXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MQN2V0Tt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Bnintw71_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Gj9Yx5eM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MQN2V0Tt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Bnintw71_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_WUvJWRzs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hzPxIhTS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_zLZrkvtq_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_eWRwbJSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hzPxIhTS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_zLZrkvtq_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_IxIjy1yy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_W0tl2A2U_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LdJZCSFU_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_LVYvSO28_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_W0tl2A2U_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LdJZCSFU_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ge7oGx4w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_Gj9Yx5eM_sendMessage(_c, 0, m);
  cMsg_eWRwbJSp_sendMessage(_c, 0, m);
  cMsg_LVYvSO28_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_RYfL0apr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_Gj9Yx5eM_sendMessage(_c, 0, m);
  cMsg_WUvJWRzs_sendMessage(_c, 0, m);
  cMsg_IxIjy1yy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_QowWabDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_3NLjbXXF_sendMessage(_c, 0, m);
  cMsg_WUvJWRzs_sendMessage(_c, 0, m);
  cMsg_LVYvSO28_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_dof2096m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_Pe5JM6yV_sendMessage(_c, 0, m);
  cMsg_xkWh7DQO_sendMessage(_c, 0, m);
  cMsg_8NXIGyFk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_zETkiTAq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_3NLjbXXF_sendMessage(_c, 0, m);
  cMsg_eWRwbJSp_sendMessage(_c, 0, m);
  cMsg_IxIjy1yy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_1d0fxZ2T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JAdTv5e7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_LyKDXWyn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Kcdez81n, 0, m, &cSlice_Kcdez81n_sendMessage);
      break;
    }
    default: {
      cSwitchcase_jhQhRycZ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_Kcdez81n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0E9SOPVu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0E9SOPVu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_X2zZBH7Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0E9SOPVu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_0E9SOPVu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0PwMitDv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_NCOZqNpf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_pQOccOX6, 0, m, &cSlice_pQOccOX6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_glk0GY2M_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_pQOccOX6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GiqFrEO4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GiqFrEO4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_iHC1YKkG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GiqFrEO4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_GiqFrEO4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RX2magDI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_glk0GY2M_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XvaEznUX, 0, m, &cSlice_XvaEznUX_sendMessage);
      break;
    }
    default: {
      cSwitchcase_LyKDXWyn_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_XvaEznUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NVnaKBup_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NVnaKBup_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_vw3ScSwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NVnaKBup_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_NVnaKBup_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WT8fUvuN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_jhQhRycZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5URpgoK2, 0, m, &cSlice_5URpgoK2_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Q0bJguZd_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_5URpgoK2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xxx2dMx4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xxx2dMx4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_AKr8nFoX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xxx2dMx4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_xxx2dMx4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hWXLjUds_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_Q0bJguZd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qr3IDEY8, 0, m, &cSlice_qr3IDEY8_sendMessage);
      break;
    }
    default: {
      cSwitchcase_g9Ql5aSY_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_qr3IDEY8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xSNs5DW4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xSNs5DW4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_zuePTHp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xSNs5DW4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_xSNs5DW4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2CsfgG9d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_CMMzespj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_F9FzUKXJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_F9FzUKXJ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_rWPodFI0, 1, m, &cDelay_rWPodFI0_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LZzh5SNu_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_rWPodFI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rWPodFI0, m);
  cMsg_S1DUEuDP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_F9FzUKXJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_rWPodFI0, 0, m, &cDelay_rWPodFI0_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_LZzh5SNu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_rWPodFI0, 0, m, &cDelay_rWPodFI0_sendMessage);
}

void Heavy_WSTD_MANGLR::cVar_nXWYifJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9uzbjY46, HV_BINOP_SUBTRACT, 0, m, &cBinop_9uzbjY46_sendMessage);
}

void Heavy_WSTD_MANGLR::cIf_vziYoy3K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PasZFhfZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_XmnsnzEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PasZFhfZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::sEnv_Wtw0GUeH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nXWYifJ6, 0, m, &cVar_nXWYifJ6_sendMessage);
}

void Heavy_WSTD_MANGLR::sEnv_DrObLSba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aYtlAHjF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VeB23oCj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FZ9VdxTG_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_9uzbjY46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wl3eZRht_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_wl3eZRht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_9KErg4qF_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_9KErg4qF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_B6ylrv2P_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_7iNavZ4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HHySNVK4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MmFXaURZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_HHySNVK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vziYoy3K, 1, m, &cIf_vziYoy3K_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_MmFXaURZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uw4zwq7J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_0F1RN8vi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XmnsnzEg, 1, m, &cIf_XmnsnzEg_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_uw4zwq7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_vziYoy3K, 0, m, &cIf_vziYoy3K_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_B6ylrv2P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XmnsnzEg, 0, m, &cIf_XmnsnzEg_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_VeB23oCj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9uzbjY46, HV_BINOP_SUBTRACT, 1, m, &cBinop_9uzbjY46_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_aYtlAHjF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_MANGLR::cCast_FZ9VdxTG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nXWYifJ6, 0, m, &cVar_nXWYifJ6_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_PasZFhfZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fQJIP8Ek, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSwitchcase_g9Ql5aSY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_x7OXI6b6, 0, m, &cSlice_x7OXI6b6_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_x7OXI6b6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_amfT2AgM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_amfT2AgM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_acsrg6T9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_amfT2AgM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_amfT2AgM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9L3QVJzj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_xAzfaPD2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Q8psKNZG, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_xpbk5IWc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HLd4v4O1, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_Bf9I2Waj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_c5mf1clt, 0, m, &cVar_c5mf1clt_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_JAdTv5e7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VeK86sD3, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_hHztLITt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9U4s4Sxb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_Ho74zzXs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_CMMzespj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_S1DUEuDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_h7bIsxRj, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_9U4s4Sxb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_h7bIsxRj, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_pL4lZbcl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_C8WBOZzj_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_C8WBOZzj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uiiPpFWC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_uiiPpFWC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Dsz2iBJg, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cVar_uBweunM3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_URlzXmXc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Yf78NnL7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZC8Rf3e5, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_VMhy3yb3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2mQEa76s, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSend_pCOC6aGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tBF9gqZh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_s6dZb2m7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_kySda359_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_NCOZqNpf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_vimH59Sz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_kySda359_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_NCOZqNpf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_y80x44BQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PXhJ5RdN, 0, m, &cVar_PXhJ5RdN_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_mw8HFibN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_kySda359_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_NCOZqNpf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_4qCrMEhM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_kySda359_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_NCOZqNpf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_ndlg7Oj6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_kySda359_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_NCOZqNpf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_v9aTvFDC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_zOOKXITg, 0, m, &cVar_zOOKXITg_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_kvnBGoDu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_TIYJj84S, 0, m, &cVar_TIYJj84S_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PcMmMQ1z, 0, m, &cVar_PcMmMQ1z_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Ni2wpFgP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_y80x44BQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_u8BBwNbT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_4xVD7IB9, 0, m, &cVar_4xVD7IB9_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_URlzXmXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_kySda359_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_NCOZqNpf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Smdzmd5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_uBweunM3, 0, m, &cVar_uBweunM3_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_tBF9gqZh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_icek4v4e_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_Smn1LcUm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NnFQC02Z, 0, m, &cVar_NnFQC02Z_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_uaPIeLye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_y80x44BQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_fKeWCIpK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zOOKXITg, 0, m, &cVar_zOOKXITg_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_3IUEhKcN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sorhhRPl, 0, m, &cVar_sorhhRPl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EColGcM4, 0, m, &cVar_EColGcM4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3Psh4dKO, 0, m, &cVar_3Psh4dKO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CLjfhHWW, 0, m, &cVar_CLjfhHWW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Szmwv7FY, 0, m, &cVar_Szmwv7FY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aA5vH6l1, 0, m, &cVar_aA5vH6l1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_X2zZBH7Z, 0, m, &cVar_X2zZBH7Z_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iHC1YKkG, 0, m, &cVar_iHC1YKkG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vw3ScSwF, 0, m, &cVar_vw3ScSwF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AKr8nFoX, 0, m, &cVar_AKr8nFoX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zuePTHp5, 0, m, &cVar_zuePTHp5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_acsrg6T9, 0, m, &cVar_acsrg6T9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iT3esoXs_sendMessage);
  cMsg_u8BBwNbT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_8Acs77G2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4xVD7IB9, 0, m, &cVar_4xVD7IB9_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_OQ9dvt8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TIYJj84S, 0, m, &cVar_TIYJj84S_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_ROHy0QDD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PcMmMQ1z, 0, m, &cVar_PcMmMQ1z_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_rLgreRKT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8ivWCotc, 0, m, &cVar_8ivWCotc_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_a1rQ6Pka_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DvUsMCNE, 0, m, &cVar_DvUsMCNE_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_DOjfhsGp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_RxvjtDjF_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_BcUCxyIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_FR9sOHX5_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oSnpOx8E_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_M852Uu8W_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_YdbgW1jH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_UdS6uvn8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_UCneoRUo_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_E2CnPw4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2aZg1XPn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_0PwMitDv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NacoAsBN, 0, m, &cVar_NacoAsBN_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_hWXLjUds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1d0fxZ2T, 0, m, &cVar_1d0fxZ2T_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_WT8fUvuN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_Bf9I2Waj_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_RX2magDI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_sjCA0yp4_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hHztLITt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ho74zzXs_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_2CsfgG9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7iNavZ4S_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0F1RN8vi_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_9L3QVJzj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pL4lZbcl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_YlFZRXyo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uBweunM3, 0, m, &cVar_uBweunM3_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_MANGLR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varwrite_f(&sVarf_670Lzilk, VIf(I0));
    __hv_varread_f(&sVarf_B9lhuAGz, VOf(Bf0));
    __hv_varread_f(&sVarf_FsbK5iFM, VOf(Bf1));
    __hv_varread_f(&sVarf_xT0Pc788, VOf(Bf2));
    __hv_varread_f(&sVarf_d1800YhA, VOf(Bf3));
    __hv_varread_f(&sVarf_m0DNPezF, VOf(Bf4));
    __hv_varread_f(&sVarf_oJlT3zb7, VOf(Bf5));
    __hv_varread_f(&sVarf_z4yoMAHs, VOf(Bf6));
    __hv_varwrite_f(&sVarf_ffqRprqn, VIf(I0));
    __hv_varread_f(&sVarf_qHqwsHNg, VOf(Bf7));
    __hv_line_f(&sLine_WqlcTdqD, VOf(Bf8));
    __hv_mul_f(VIf(Bf7), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_jnZ32q2h, VOf(Bf9));
    __hv_line_f(&sLine_Rn0Xkg1y, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_S40HZLde, VOf(Bf8));
    __hv_line_f(&sLine_rp3wD9rq, VOf(Bf11));
    __hv_mul_f(VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_varwrite_f(&sVarf_d1800YhA, VIf(Bf11));
    __hv_varread_f(&sVarf_ffqRprqn, VOf(Bf11));
    __hv_line_f(&sLine_0WFl1CmR, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_dd3EDFDj, VOf(Bf12));
    __hv_mul_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_lEIo5vcb, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_m0DNPezF, VIf(Bf10));
    __hv_line_f(&sLine_huB7Y2WV, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_SySItBN8, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_xO1ntkR7, VOf(Bf10));
    __hv_mul_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_oJlT3zb7, VIf(Bf10));
    __hv_line_f(&sLine_SESCXPR5, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_E6Akevzs, VOf(Bf11));
    __hv_mul_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_fWC4fTQn, VOf(Bf10));
    __hv_mul_f(VIf(Bf7), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_z4yoMAHs, VIf(Bf10));
    __hv_varwrite_f(&sVarf_qHqwsHNg, VIf(Bf0));
    __hv_varwrite_f(&sVarf_jnZ32q2h, VIf(Bf1));
    __hv_varwrite_f(&sVarf_S40HZLde, VIf(Bf2));
    sEnv_process(this, &sEnv_nbunmxn0, VIf(Bf3), &sEnv_nbunmxn0_sendMessage);
    sEnv_process(this, &sEnv_oXOfsHRh, VIf(I0), &sEnv_oXOfsHRh_sendMessage);
    __hv_line_f(&sLine_f4ctMpoG, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_exp_f(VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_gCoVXxsJ, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_Ir7HPw0m, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_exp_f(VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_MrV0XEXO, VOf(Bf3));
    __hv_line_f(&sLine_DeCdipZ6, VOf(Bf1));
    __hv_var_k_f(VOf(Bf0), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf3), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf3));
    __hv_sub_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_div_f(VIf(Bf3), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_B9lhuAGz, VIf(Bf0));
    __hv_varwrite_f(&sVarf_MrV0XEXO, VIf(Bf4));
    __hv_varwrite_f(&sVarf_hpJ6ak4w, VIf(Bf5));
    __hv_varwrite_f(&sVarf_Edw4EHVf, VIf(Bf6));
    __hv_varread_f(&sVarf_Edw4EHVf, VOf(Bf6));
    __hv_line_f(&sLine_iF0MyzzS, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf6), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf5), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf5), VOf(Bf6));
    __hv_var_k_f(VOf(Bf4), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf0));
    __hv_var_k_f(VOf(Bf3), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_div_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf5), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_xT0Pc788, VIf(Bf4));
    __hv_varread_f(&sVarf_hpJ6ak4w, VOf(Bf4));
    __hv_line_f(&sLine_9A5WEpUm, VOf(Bf5));
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf4), VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf5), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_floor_f(VIf(Bf5), VOf(Bf0));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_abs_f(VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf4), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf5), VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_neg_f(VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_FsbK5iFM, VIf(Bf4));
    __hv_varwrite_f(&sVarf_wEkPf3Zi, VIf(Bf2));
    __hv_varwrite_f(&sVarf_NC1HmHvH, VIf(I1));
    __hv_varread_f(&sVarf_Q4ey7pyx, VOf(Bf2));
    __hv_varread_f(&sVarf_oHGh5CZB, VOf(Bf4));
    __hv_varread_f(&sVarf_23av4EMO, VOf(Bf0));
    __hv_varread_f(&sVarf_wvYBB5N0, VOf(Bf5));
    __hv_varread_f(&sVarf_WDxp3u8O, VOf(Bf3));
    __hv_varread_f(&sVarf_wwBRkokE, VOf(Bf6));
    __hv_varread_f(&sVarf_UOPeTe1m, VOf(Bf1));
    __hv_varwrite_f(&sVarf_jP8Zpr5L, VIf(I1));
    __hv_varread_f(&sVarf_nSgd3l3S, VOf(Bf10));
    __hv_line_f(&sLine_1qO2CIPA, VOf(Bf11));
    __hv_mul_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_HPKEEgF9, VOf(Bf7));
    __hv_line_f(&sLine_lwFsnvKi, VOf(Bf9));
    __hv_mul_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_I1hb4J7u, VOf(Bf11));
    __hv_line_f(&sLine_DdMLqQ1n, VOf(Bf12));
    __hv_mul_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_wvYBB5N0, VIf(Bf12));
    __hv_varread_f(&sVarf_jP8Zpr5L, VOf(Bf12));
    __hv_line_f(&sLine_VtpwnTD0, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_gGv292lZ, VOf(Bf8));
    __hv_mul_f(VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_5LJkXRmk, VOf(Bf9));
    __hv_mul_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_WDxp3u8O, VIf(Bf9));
    __hv_line_f(&sLine_HCVn7SlN, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_BPBtlzqv, VOf(Bf8));
    __hv_mul_f(VIf(Bf10), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_6NVw6gWs, VOf(Bf9));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_wwBRkokE, VIf(Bf9));
    __hv_line_f(&sLine_XXb9kCR5, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_FNnbHw25, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_btTEoo8f, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_UOPeTe1m, VIf(Bf9));
    __hv_varwrite_f(&sVarf_nSgd3l3S, VIf(Bf2));
    __hv_varwrite_f(&sVarf_HPKEEgF9, VIf(Bf4));
    __hv_varwrite_f(&sVarf_I1hb4J7u, VIf(Bf0));
    sEnv_process(this, &sEnv_Wtw0GUeH, VIf(Bf5), &sEnv_Wtw0GUeH_sendMessage);
    sEnv_process(this, &sEnv_DrObLSba, VIf(I1), &sEnv_DrObLSba_sendMessage);
    __hv_line_f(&sLine_fQJIP8Ek, VOf(Bf0));
    __hv_var_k_f(VOf(Bf4), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_h7bIsxRj, VOf(Bf5));
    __hv_mul_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_Dsz2iBJg, VOf(Bf0));
    __hv_var_k_f(VOf(Bf4), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_7vorwxen, VOf(Bf5));
    __hv_line_f(&sLine_HLd4v4O1, VOf(Bf4));
    __hv_var_k_f(VOf(Bf2), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf4), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf5));
    __hv_sub_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_div_f(VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_Q4ey7pyx, VIf(Bf2));
    __hv_varwrite_f(&sVarf_7vorwxen, VIf(Bf3));
    __hv_varwrite_f(&sVarf_HyjJ8O4i, VIf(Bf6));
    __hv_varwrite_f(&sVarf_74iFaBF1, VIf(Bf1));
    __hv_varread_f(&sVarf_74iFaBF1, VOf(Bf1));
    __hv_line_f(&sLine_VeK86sD3, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf1), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf6), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf6), VIf(Bf6), VOf(Bf1));
    __hv_var_k_f(VOf(Bf3), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf2));
    __hv_var_k_f(VOf(Bf5), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf1), VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_div_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_23av4EMO, VIf(Bf3));
    __hv_varread_f(&sVarf_HyjJ8O4i, VOf(Bf3));
    __hv_line_f(&sLine_Q8psKNZG, VOf(Bf6));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf3), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf2));
    __hv_sub_f(VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_abs_f(VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf2), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf6), VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_oHGh5CZB, VIf(Bf3));
    __hv_varwrite_f(&sVarf_9ViDh31u, VIf(Bf0));
    __hv_varread_f(&sVarf_670Lzilk, VOf(Bf0));
    __hv_line_f(&sLine_2mQEa76s, VOf(Bf3));
    __hv_varread_f(&sVarf_wEkPf3Zi, VOf(Bf2));
    __hv_line_f(&sLine_ZC8Rf3e5, VOf(Bf6));
    __hv_mul_f(VIf(Bf2), VIf(Bf6), VOf(Bf2));
    __hv_fma_f(VIf(Bf0), VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_NC1HmHvH, VOf(Bf2));
    __hv_varread_f(&sVarf_9ViDh31u, VOf(Bf0));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_MANGLR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_MANGLR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
